//line parser/parser.y:2
package parser

import __yyfmt__ "fmt"

//line parser/parser.y:2
import (
	"fmt"
	"github.com/z7zmey/php-parser/node"
	"github.com/z7zmey/php-parser/node/expr"
	"github.com/z7zmey/php-parser/node/expr/assign_op"
	"github.com/z7zmey/php-parser/node/expr/binary_op"
	"github.com/z7zmey/php-parser/node/expr/cast"
	"github.com/z7zmey/php-parser/node/name"
	"github.com/z7zmey/php-parser/node/scalar"
	"github.com/z7zmey/php-parser/node/stmt"
	"github.com/z7zmey/php-parser/token"
	"io"
)

var rootnode = node.NewSimpleNode("Root")

func Parse(src io.Reader, fName string) node.Node {
	yyDebug = 0
	yyErrorVerbose = true
	rootnode = node.NewSimpleNode("Root") //reset
	yyParse(newLexer(src, fName))
	return rootnode
}

//line parser/parser.y:30
type yySymType struct {
	yys     int
	node    node.Node
	token   token.Token
	value   string
	list    []node.Node
	strings []string
}

const T_INCLUDE = 57346
const T_INCLUDE_ONCE = 57347
const T_EVAL = 57348
const T_REQUIRE = 57349
const T_REQUIRE_ONCE = 57350
const T_LOGICAL_OR = 57351
const T_LOGICAL_XOR = 57352
const T_LOGICAL_AND = 57353
const T_PRINT = 57354
const T_YIELD = 57355
const T_DOUBLE_ARROW = 57356
const T_YIELD_FROM = 57357
const T_PLUS_EQUAL = 57358
const T_MINUS_EQUAL = 57359
const T_MUL_EQUAL = 57360
const T_DIV_EQUAL = 57361
const T_CONCAT_EQUAL = 57362
const T_MOD_EQUAL = 57363
const T_AND_EQUAL = 57364
const T_OR_EQUAL = 57365
const T_XOR_EQUAL = 57366
const T_SL_EQUAL = 57367
const T_SR_EQUAL = 57368
const T_POW_EQUAL = 57369
const T_COALESCE = 57370
const T_BOOLEAN_OR = 57371
const T_BOOLEAN_AND = 57372
const T_IS_EQUAL = 57373
const T_IS_NOT_EQUAL = 57374
const T_IS_IDENTICAL = 57375
const T_IS_NOT_IDENTICAL = 57376
const T_SPACESHIP = 57377
const T_IS_SMALLER_OR_EQUAL = 57378
const T_IS_GREATER_OR_EQUAL = 57379
const T_SL = 57380
const T_SR = 57381
const T_INSTANCEOF = 57382
const T_INC = 57383
const T_DEC = 57384
const T_INT_CAST = 57385
const T_DOUBLE_CAST = 57386
const T_STRING_CAST = 57387
const T_ARRAY_CAST = 57388
const T_OBJECT_CAST = 57389
const T_BOOL_CAST = 57390
const T_UNSET_CAST = 57391
const T_POW = 57392
const T_NEW = 57393
const T_CLONE = 57394
const T_NOELSE = 57395
const T_ELSEIF = 57396
const T_ELSE = 57397
const T_ENDIF = 57398
const T_STATIC = 57399
const T_ABSTRACT = 57400
const T_FINAL = 57401
const T_PRIVATE = 57402
const T_PROTECTED = 57403
const T_PUBLIC = 57404
const T_EXIT = 57405
const T_IF = 57406
const T_LNUMBER = 57407
const T_DNUMBER = 57408
const T_STRING = 57409
const T_STRING_VARNAME = 57410
const T_VARIABLE = 57411
const T_NUM_STRING = 57412
const T_INLINE_HTML = 57413
const T_CHARACTER = 57414
const T_BAD_CHARACTER = 57415
const T_ENCAPSED_AND_WHITESPACE = 57416
const T_CONSTANT_ENCAPSED_STRING = 57417
const T_ECHO = 57418
const T_DO = 57419
const T_WHILE = 57420
const T_ENDWHILE = 57421
const T_FOR = 57422
const T_ENDFOR = 57423
const T_FOREACH = 57424
const T_ENDFOREACH = 57425
const T_DECLARE = 57426
const T_ENDDECLARE = 57427
const T_AS = 57428
const T_SWITCH = 57429
const T_ENDSWITCH = 57430
const T_CASE = 57431
const T_DEFAULT = 57432
const T_BREAK = 57433
const T_CONTINUE = 57434
const T_GOTO = 57435
const T_FUNCTION = 57436
const T_CONST = 57437
const T_RETURN = 57438
const T_TRY = 57439
const T_CATCH = 57440
const T_FINALLY = 57441
const T_THROW = 57442
const T_USE = 57443
const T_INSTEADOF = 57444
const T_GLOBAL = 57445
const T_VAR = 57446
const T_UNSET = 57447
const T_ISSET = 57448
const T_EMPTY = 57449
const T_HALT_COMPILER = 57450
const T_CLASS = 57451
const T_TRAIT = 57452
const T_INTERFACE = 57453
const T_EXTENDS = 57454
const T_IMPLEMENTS = 57455
const T_OBJECT_OPERATOR = 57456
const T_LIST = 57457
const T_ARRAY = 57458
const T_CALLABLE = 57459
const T_CLASS_C = 57460
const T_TRAIT_C = 57461
const T_METHOD_C = 57462
const T_FUNC_C = 57463
const T_LINE = 57464
const T_FILE = 57465
const T_COMMENT = 57466
const T_DOC_COMMENT = 57467
const T_OPEN_TAG = 57468
const T_OPEN_TAG_WITH_ECHO = 57469
const T_CLOSE_TAG = 57470
const T_WHITESPACE = 57471
const T_START_HEREDOC = 57472
const T_END_HEREDOC = 57473
const T_DOLLAR_OPEN_CURLY_BRACES = 57474
const T_CURLY_OPEN = 57475
const T_PAAMAYIM_NEKUDOTAYIM = 57476
const T_NAMESPACE = 57477
const T_NS_C = 57478
const T_DIR = 57479
const T_NS_SEPARATOR = 57480
const T_ELLIPSIS = 57481

var yyToknames = [...]string{
	"$end",
	"error",
	"$unk",
	"T_INCLUDE",
	"T_INCLUDE_ONCE",
	"T_EVAL",
	"T_REQUIRE",
	"T_REQUIRE_ONCE",
	"','",
	"T_LOGICAL_OR",
	"T_LOGICAL_XOR",
	"T_LOGICAL_AND",
	"T_PRINT",
	"T_YIELD",
	"T_DOUBLE_ARROW",
	"T_YIELD_FROM",
	"'='",
	"T_PLUS_EQUAL",
	"T_MINUS_EQUAL",
	"T_MUL_EQUAL",
	"T_DIV_EQUAL",
	"T_CONCAT_EQUAL",
	"T_MOD_EQUAL",
	"T_AND_EQUAL",
	"T_OR_EQUAL",
	"T_XOR_EQUAL",
	"T_SL_EQUAL",
	"T_SR_EQUAL",
	"T_POW_EQUAL",
	"'?'",
	"':'",
	"T_COALESCE",
	"T_BOOLEAN_OR",
	"T_BOOLEAN_AND",
	"'|'",
	"'^'",
	"'&'",
	"T_IS_EQUAL",
	"T_IS_NOT_EQUAL",
	"T_IS_IDENTICAL",
	"T_IS_NOT_IDENTICAL",
	"T_SPACESHIP",
	"'<'",
	"T_IS_SMALLER_OR_EQUAL",
	"'>'",
	"T_IS_GREATER_OR_EQUAL",
	"T_SL",
	"T_SR",
	"'+'",
	"'-'",
	"'.'",
	"'*'",
	"'/'",
	"'%'",
	"'!'",
	"T_INSTANCEOF",
	"'~'",
	"T_INC",
	"T_DEC",
	"T_INT_CAST",
	"T_DOUBLE_CAST",
	"T_STRING_CAST",
	"T_ARRAY_CAST",
	"T_OBJECT_CAST",
	"T_BOOL_CAST",
	"T_UNSET_CAST",
	"'@'",
	"T_POW",
	"'['",
	"T_NEW",
	"T_CLONE",
	"T_NOELSE",
	"T_ELSEIF",
	"T_ELSE",
	"T_ENDIF",
	"T_STATIC",
	"T_ABSTRACT",
	"T_FINAL",
	"T_PRIVATE",
	"T_PROTECTED",
	"T_PUBLIC",
	"T_EXIT",
	"T_IF",
	"T_LNUMBER",
	"T_DNUMBER",
	"T_STRING",
	"T_STRING_VARNAME",
	"T_VARIABLE",
	"T_NUM_STRING",
	"T_INLINE_HTML",
	"T_CHARACTER",
	"T_BAD_CHARACTER",
	"T_ENCAPSED_AND_WHITESPACE",
	"T_CONSTANT_ENCAPSED_STRING",
	"T_ECHO",
	"T_DO",
	"T_WHILE",
	"T_ENDWHILE",
	"T_FOR",
	"T_ENDFOR",
	"T_FOREACH",
	"T_ENDFOREACH",
	"T_DECLARE",
	"T_ENDDECLARE",
	"T_AS",
	"T_SWITCH",
	"T_ENDSWITCH",
	"T_CASE",
	"T_DEFAULT",
	"T_BREAK",
	"T_CONTINUE",
	"T_GOTO",
	"T_FUNCTION",
	"T_CONST",
	"T_RETURN",
	"T_TRY",
	"T_CATCH",
	"T_FINALLY",
	"T_THROW",
	"T_USE",
	"T_INSTEADOF",
	"T_GLOBAL",
	"T_VAR",
	"T_UNSET",
	"T_ISSET",
	"T_EMPTY",
	"T_HALT_COMPILER",
	"T_CLASS",
	"T_TRAIT",
	"T_INTERFACE",
	"T_EXTENDS",
	"T_IMPLEMENTS",
	"T_OBJECT_OPERATOR",
	"T_LIST",
	"T_ARRAY",
	"T_CALLABLE",
	"T_CLASS_C",
	"T_TRAIT_C",
	"T_METHOD_C",
	"T_FUNC_C",
	"T_LINE",
	"T_FILE",
	"T_COMMENT",
	"T_DOC_COMMENT",
	"T_OPEN_TAG",
	"T_OPEN_TAG_WITH_ECHO",
	"T_CLOSE_TAG",
	"T_WHITESPACE",
	"T_START_HEREDOC",
	"T_END_HEREDOC",
	"T_DOLLAR_OPEN_CURLY_BRACES",
	"T_CURLY_OPEN",
	"T_PAAMAYIM_NEKUDOTAYIM",
	"T_NAMESPACE",
	"T_NS_C",
	"T_DIR",
	"T_NS_SEPARATOR",
	"T_ELLIPSIS",
	"'\"'",
	"'`'",
	"'{'",
	"'}'",
	"';'",
	"'('",
	"')'",
	"']'",
	"'$'",
}
var yyStatenames = [...]string{}

const yyEofCode = 1
const yyErrCode = 2
const yyInitialStackSize = 16

//line parser/parser.y:1152

//line yacctab:1
var yyExca = [...]int{
	-1, 1,
	1, -1,
	-2, 0,
	-1, 43,
	69, 419,
	133, 419,
	153, 419,
	161, 419,
	-2, 414,
	-1, 47,
	164, 422,
	-2, 431,
	-1, 83,
	69, 421,
	133, 421,
	153, 421,
	161, 421,
	164, 424,
	-2, 409,
	-1, 106,
	153, 382,
	-2, 411,
	-1, 228,
	69, 419,
	133, 419,
	153, 419,
	161, 419,
	-2, 311,
	-1, 231,
	164, 424,
	-2, 421,
	-1, 234,
	69, 419,
	133, 419,
	153, 419,
	161, 419,
	-2, 313,
	-1, 352,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 335,
	-1, 353,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 336,
	-1, 354,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 337,
	-1, 355,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 338,
	-1, 356,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 339,
	-1, 357,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 340,
	-1, 358,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 341,
	-1, 359,
	43, 0,
	44, 0,
	45, 0,
	46, 0,
	-2, 342,
	-1, 360,
	38, 0,
	39, 0,
	40, 0,
	41, 0,
	42, 0,
	-2, 343,
	-1, 367,
	9, 161,
	165, 161,
	-2, 419,
	-1, 374,
	165, 211,
	-2, 216,
	-1, 411,
	9, 459,
	165, 459,
	166, 459,
	-2, 419,
	-1, 415,
	69, 420,
	133, 420,
	153, 420,
	161, 420,
	164, 423,
	-2, 345,
	-1, 429,
	164, 445,
	-2, 412,
	-1, 430,
	164, 447,
	-2, 437,
	-1, 509,
	164, 445,
	-2, 413,
	-1, 510,
	164, 447,
	-2, 438,
	-1, 558,
	165, 211,
	-2, 216,
	-1, 568,
	165, 211,
	-2, 216,
	-1, 603,
	164, 423,
	-2, 420,
	-1, 659,
	15, 181,
	165, 181,
	-2, 419,
	-1, 681,
	88, 263,
	-2, 266,
	-1, 700,
	9, 458,
	165, 458,
	166, 458,
	-2, 419,
	-1, 733,
	15, 182,
	165, 182,
	-2, 419,
	-1, 786,
	15, 184,
	165, 184,
	-2, 393,
	-1, 857,
	105, 76,
	-2, 80,
	-1, 880,
	165, 211,
	-2, 216,
}

const yyPrivate = 57344

const yyLast = 7405

var yyAct = [...]int{

	27, 129, 790, 802, 585, 683, 434, 569, 836, 849,
	801, 781, 818, 749, 106, 125, 573, 658, 741, 583,
	640, 137, 137, 137, 725, 714, 150, 311, 110, 639,
	4, 320, 520, 571, 185, 530, 366, 563, 580, 114,
	120, 574, 222, 403, 220, 131, 188, 79, 149, 376,
	146, 315, 224, 227, 8, 83, 235, 236, 237, 238,
	239, 43, 136, 240, 241, 242, 243, 244, 245, 246,
	314, 249, 142, 7, 257, 258, 259, 313, 127, 312,
	6, 428, 5, 512, 139, 140, 511, 786, 272, 273,
	126, 275, 276, 707, 124, 732, 703, 253, 263, 268,
	617, 229, 229, 2, 604, 592, 875, 232, 104, 231,
	231, 81, 307, 408, 906, 228, 234, 116, 892, 104,
	827, 104, 826, 816, 808, 740, 729, 712, 710, 702,
	668, 317, 656, 644, 635, 322, 323, 305, 605, 691,
	289, 596, 291, 290, 373, 288, 914, 298, 913, 293,
	304, 292, 819, 335, 336, 337, 338, 339, 340, 341,
	342, 343, 344, 345, 346, 347, 348, 349, 350, 351,
	352, 353, 354, 355, 356, 357, 358, 359, 360, 319,
	362, 364, 404, 368, 104, 133, 370, 105, 111, 880,
	284, 286, 331, 268, 282, 908, 265, 78, 105, 844,
	105, 386, 388, 389, 390, 391, 392, 393, 394, 395,
	396, 397, 398, 399, 798, 793, 400, 137, 402, 294,
	224, 143, 374, 788, 382, 734, 775, 776, 701, 229,
	285, 413, 568, 558, 224, 775, 776, 231, 374, 552,
	550, 412, 383, 367, 301, 731, 381, 287, 232, 137,
	687, 688, 689, 686, 685, 684, 423, 405, 116, 274,
	104, 137, 874, 105, 407, 429, 509, 514, 566, 271,
	334, 521, 522, 229, 369, 523, 330, 361, 414, 401,
	821, 231, 269, 527, 820, 328, 531, 411, 224, 774,
	265, 806, 270, 805, 680, 248, 219, 682, 215, 307,
	267, 301, 183, 283, 229, 182, 660, 181, 135, 549,
	134, 416, 231, 130, 112, 305, 891, 884, 425, 883,
	865, 828, 4, 427, 822, 815, 133, 772, 541, 111,
	544, 516, 533, 559, 759, 150, 858, 116, 662, 105,
	730, 728, 726, 724, 508, 232, 8, 721, 614, 418,
	419, 517, 553, 843, 518, 116, 538, 104, 535, 515,
	384, 653, 372, 109, 562, 7, 326, 325, 797, 324,
	295, 216, 6, 859, 5, 418, 269, 419, 419, 418,
	814, 557, 587, 560, 588, 811, 548, 589, 590, 578,
	809, 768, 582, 615, 905, 586, 542, 536, 539, 866,
	834, 556, 832, 661, 108, 789, 595, 764, 113, 746,
	224, 599, 115, 224, 674, 534, 406, 584, 534, 378,
	184, 745, 417, 133, 333, 579, 111, 616, 113, 288,
	329, 887, 619, 230, 534, 218, 105, 513, 534, 327,
	116, 613, 154, 156, 155, 687, 688, 689, 686, 685,
	684, 116, 598, 306, 262, 300, 254, 602, 303, 430,
	510, 420, 179, 217, 180, 152, 153, 157, 159, 158,
	171, 172, 169, 170, 177, 173, 174, 175, 176, 167,
	168, 161, 162, 160, 163, 165, 166, 594, 178, 680,
	716, 652, 682, 643, 687, 688, 689, 686, 685, 684,
	164, 687, 688, 689, 686, 685, 684, 116, 133, 637,
	288, 111, 618, 545, 261, 137, 623, 581, 303, 255,
	256, 377, 543, 380, 885, 421, 143, 526, 742, 738,
	739, 840, 116, 634, 122, 123, 145, 116, 680, 303,
	147, 682, 254, 303, 886, 680, 254, 303, 682, 119,
	318, 420, 704, 648, 322, 650, 876, 627, 750, 305,
	624, 641, 655, 794, 4, 145, 654, 632, 626, 575,
	638, 870, 544, 578, 544, 147, 667, 622, 121, 646,
	796, 576, 577, 578, 116, 649, 675, 755, 8, 422,
	578, 547, 620, 611, 664, 540, 586, 723, 699, 302,
	133, 657, 128, 111, 690, 255, 256, 7, 299, 255,
	256, 546, 229, 229, 6, 705, 5, 672, 673, 695,
	231, 231, 752, 751, 869, 116, 367, 659, 254, 521,
	823, 775, 776, 420, 531, 687, 688, 689, 686, 685,
	684, 254, 778, 775, 776, 164, 281, 534, 229, 722,
	76, 77, 375, 715, 194, 254, 231, 193, 719, 641,
	277, 711, 700, 224, 254, 709, 544, 736, 297, 713,
	252, 544, 544, 720, 576, 577, 192, 717, 727, 680,
	838, 186, 682, 260, 578, 753, 45, 754, 195, 196,
	525, 255, 256, 133, 747, 586, 111, 189, 760, 761,
	178, 190, 224, 743, 255, 256, 756, 735, 229, 116,
	671, 621, 164, 791, 406, 625, 231, 278, 255, 256,
	757, 676, 733, 758, 191, 322, 524, 255, 256, 609,
	385, 837, 715, 254, 641, 224, 122, 123, 251, 769,
	187, 698, 767, 845, 792, 544, 762, 544, 780, 839,
	784, 777, 765, 779, 691, 799, 773, 597, 770, 782,
	807, 197, 199, 198, 332, 607, 795, 610, 608, 308,
	766, 718, 669, 279, 280, 642, 817, 633, 628, 785,
	229, 564, 812, 824, 810, 825, 554, 118, 231, 409,
	1, 831, 365, 804, 659, 544, 255, 256, 848, 803,
	842, 651, 144, 830, 748, 813, 578, 846, 833, 141,
	855, 321, 841, 687, 688, 689, 686, 685, 684, 148,
	864, 854, 167, 168, 161, 162, 160, 163, 165, 166,
	863, 178, 800, 666, 872, 829, 873, 250, 868, 37,
	877, 681, 679, 164, 861, 678, 879, 221, 223, 835,
	42, 912, 855, 529, 782, 878, 570, 41, 882, 15,
	14, 519, 606, 854, 888, 889, 266, 48, 890, 87,
	88, 89, 90, 91, 47, 107, 49, 82, 73, 74,
	80, 75, 71, 247, 896, 893, 61, 264, 897, 60,
	898, 902, 901, 900, 853, 578, 852, 163, 165, 166,
	586, 178, 851, 850, 677, 907, 44, 909, 572, 910,
	737, 663, 860, 164, 55, 56, 915, 645, 309, 117,
	57, 296, 58, 53, 54, 62, 63, 64, 65, 66,
	67, 68, 70, 379, 51, 84, 52, 3, 433, 744,
	670, 24, 76, 77, 0, 0, 0, 69, 46, 92,
	93, 35, 0, 104, 0, 26, 0, 0, 0, 109,
	25, 17, 16, 0, 18, 0, 29, 0, 30, 0,
	0, 19, 0, 0, 0, 20, 21, 34, 36, 12,
	22, 32, 0, 0, 33, 11, 0, 23, 0, 28,
	85, 86, 9, 38, 39, 40, 0, 0, 0, 50,
	108, 0, 101, 97, 98, 99, 94, 95, 0, 0,
	0, 0, 0, 0, 102, 0, 0, 0, 0, 10,
	100, 96, 111, 0, 103, 72, 13, 636, 31, 59,
	0, 0, 105, 87, 88, 89, 90, 91, 0, 0,
	0, 0, 73, 74, 179, 75, 180, 152, 153, 157,
	159, 158, 171, 172, 169, 170, 177, 173, 174, 175,
	176, 167, 168, 161, 162, 160, 163, 165, 166, 0,
	178, 0, 0, 0, 0, 0, 0, 0, 55, 56,
	0, 0, 164, 0, 57, 0, 58, 53, 54, 62,
	63, 64, 65, 66, 67, 68, 70, 0, 51, 84,
	52, 0, 0, 0, 0, 24, 76, 77, 0, 0,
	0, 69, 46, 92, 93, 35, 0, 104, 0, 26,
	0, 0, 0, 109, 25, 17, 16, 0, 18, 0,
	29, 0, 30, 0, 0, 19, 0, 0, 0, 20,
	21, 34, 36, 12, 22, 32, 0, 0, 33, 11,
	0, 23, 0, 28, 85, 86, 9, 38, 39, 40,
	0, 0, 0, 50, 108, 0, 101, 97, 98, 99,
	94, 95, 0, 0, 0, 0, 0, 0, 102, 0,
	0, 0, 0, 10, 100, 96, 111, 0, 103, 72,
	13, 537, 31, 59, 0, 0, 105, 87, 88, 89,
	90, 91, 0, 0, 0, 0, 73, 74, 0, 75,
	180, 152, 153, 157, 159, 158, 171, 172, 169, 170,
	177, 173, 174, 175, 176, 167, 168, 161, 162, 160,
	163, 165, 166, 0, 178, 0, 0, 0, 0, 0,
	0, 0, 55, 56, 0, 0, 164, 0, 57, 0,
	58, 53, 54, 62, 63, 64, 65, 66, 67, 68,
	70, 0, 51, 84, 52, 0, 0, 0, 0, 24,
	76, 77, 0, 0, 0, 69, 46, 92, 93, 35,
	0, 104, 0, 26, 0, 0, 0, 109, 25, 17,
	16, 0, 18, 0, 29, 0, 30, 0, 0, 19,
	0, 0, 0, 20, 21, 34, 36, 12, 22, 32,
	0, 0, 33, 11, 0, 23, 0, 28, 85, 86,
	9, 38, 39, 40, 0, 0, 0, 50, 108, 0,
	101, 97, 98, 99, 94, 95, 161, 162, 160, 163,
	165, 166, 102, 178, 0, 0, 0, 10, 100, 96,
	111, 0, 103, 72, 13, 164, 31, 59, 0, 0,
	105, 87, 88, 89, 90, 91, 0, 0, 0, 0,
	73, 74, 0, 75, 153, 157, 159, 158, 171, 172,
	169, 170, 177, 173, 174, 175, 176, 167, 168, 161,
	162, 160, 163, 165, 166, 0, 178, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 55, 56, 164, 0,
	0, 0, 57, 0, 58, 53, 54, 62, 63, 64,
	65, 66, 67, 68, 70, 0, 51, 84, 52, 0,
	0, 0, 0, 24, 76, 77, 0, 0, 0, 69,
	46, 92, 93, 35, 0, 104, 0, 26, 0, 0,
	0, 109, 25, 17, 16, 0, 18, 0, 29, 0,
	30, 0, 0, 19, 0, 0, 0, 20, 21, 34,
	36, 0, 22, 32, 0, 0, 33, 0, 0, 23,
	0, 28, 85, 86, 316, 38, 39, 40, 0, 0,
	0, 50, 108, 0, 101, 97, 98, 99, 94, 95,
	0, 0, 0, 0, 0, 0, 102, 0, 0, 0,
	0, 133, 100, 96, 111, 0, 103, 72, 13, 916,
	31, 59, 0, 0, 105, 87, 88, 89, 90, 91,
	0, 0, 0, 0, 73, 74, 0, 75, 0, 157,
	159, 158, 171, 172, 169, 170, 177, 173, 174, 175,
	176, 167, 168, 161, 162, 160, 163, 165, 166, 0,
	178, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	55, 56, 164, 0, 0, 0, 57, 0, 58, 53,
	54, 62, 63, 64, 65, 66, 67, 68, 70, 0,
	51, 84, 52, 0, 0, 0, 0, 24, 76, 77,
	0, 0, 0, 69, 46, 92, 93, 35, 0, 104,
	0, 26, 0, 0, 0, 109, 25, 17, 16, 0,
	18, 0, 29, 0, 30, 0, 0, 19, 0, 0,
	0, 20, 21, 34, 36, 0, 22, 32, 0, 0,
	33, 0, 0, 23, 0, 28, 85, 86, 316, 38,
	39, 40, 0, 0, 0, 50, 108, 0, 101, 97,
	98, 99, 94, 95, 0, 0, 0, 0, 0, 0,
	102, 0, 0, 0, 0, 133, 100, 96, 111, 0,
	103, 72, 13, 911, 31, 59, 0, 0, 105, 87,
	88, 89, 90, 91, 0, 0, 0, 0, 73, 74,
	0, 75, 0, 0, 159, 158, 171, 172, 169, 170,
	177, 173, 174, 175, 176, 167, 168, 161, 162, 160,
	163, 165, 166, 0, 178, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 55, 56, 164, 0, 0, 0,
	57, 0, 58, 53, 54, 62, 63, 64, 65, 66,
	67, 68, 70, 0, 51, 84, 52, 0, 0, 0,
	0, 24, 76, 77, 0, 0, 0, 69, 46, 92,
	93, 35, 0, 104, 0, 26, 0, 0, 0, 109,
	25, 17, 16, 0, 18, 0, 29, 0, 30, 0,
	0, 19, 0, 0, 0, 20, 21, 34, 36, 0,
	22, 32, 0, 0, 33, 0, 0, 23, 0, 28,
	85, 86, 316, 38, 39, 40, 0, 0, 0, 50,
	108, 0, 101, 97, 98, 99, 94, 95, 0, 0,
	0, 0, 0, 0, 102, 0, 0, 0, 0, 133,
	100, 96, 111, 0, 103, 72, 13, 904, 31, 59,
	0, 0, 105, 87, 88, 89, 90, 91, 0, 0,
	0, 0, 73, 74, 0, 75, 158, 171, 172, 169,
	170, 177, 173, 174, 175, 176, 167, 168, 161, 162,
	160, 163, 165, 166, 0, 178, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 164, 55, 56,
	0, 0, 0, 0, 57, 0, 58, 53, 54, 62,
	63, 64, 65, 66, 67, 68, 70, 0, 51, 84,
	52, 0, 0, 0, 0, 24, 76, 77, 0, 0,
	0, 69, 46, 92, 93, 35, 0, 104, 0, 26,
	0, 0, 0, 109, 25, 17, 16, 0, 18, 903,
	29, 0, 30, 0, 0, 19, 0, 0, 0, 20,
	21, 34, 36, 0, 22, 32, 0, 0, 33, 0,
	0, 23, 0, 28, 85, 86, 316, 38, 39, 40,
	0, 0, 0, 50, 108, 0, 101, 97, 98, 99,
	94, 95, 0, 0, 0, 0, 0, 0, 102, 0,
	0, 0, 0, 133, 100, 96, 111, 0, 103, 72,
	13, 0, 31, 59, 0, 0, 105, 87, 88, 89,
	90, 91, 0, 0, 0, 0, 73, 74, 0, 75,
	171, 172, 169, 170, 177, 173, 174, 175, 176, 167,
	168, 161, 162, 160, 163, 165, 166, 0, 178, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	164, 0, 55, 56, 0, 0, 0, 0, 57, 0,
	58, 53, 54, 62, 63, 64, 65, 66, 67, 68,
	70, 0, 51, 84, 52, 0, 0, 0, 0, 24,
	76, 77, 0, 0, 0, 69, 46, 92, 93, 35,
	0, 104, 0, 26, 0, 0, 0, 109, 25, 17,
	16, 0, 18, 0, 29, 0, 30, 0, 0, 19,
	0, 0, 0, 20, 21, 34, 36, 0, 22, 32,
	0, 0, 33, 0, 0, 23, 0, 28, 85, 86,
	316, 38, 39, 40, 0, 0, 0, 50, 108, 0,
	101, 97, 98, 99, 94, 95, 0, 0, 0, 0,
	0, 0, 102, 0, 0, 0, 0, 133, 100, 96,
	111, 0, 103, 72, 13, 895, 31, 59, 0, 0,
	105, 87, 88, 89, 90, 91, 0, 0, 0, 0,
	73, 74, 0, 75, 173, 174, 175, 176, 167, 168,
	161, 162, 160, 163, 165, 166, 0, 178, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 164,
	0, 0, 0, 0, 0, 0, 55, 56, 0, 0,
	0, 0, 57, 0, 58, 53, 54, 62, 63, 64,
	65, 66, 67, 68, 70, 0, 51, 84, 52, 0,
	0, 0, 0, 24, 76, 77, 0, 0, 0, 69,
	46, 92, 93, 35, 0, 104, 0, 26, 0, 0,
	0, 109, 25, 17, 16, 0, 18, 0, 29, 0,
	30, 0, 0, 19, 0, 0, 0, 20, 21, 34,
	36, 0, 22, 32, 0, 0, 33, 0, 0, 23,
	0, 28, 85, 86, 316, 38, 39, 40, 0, 0,
	0, 50, 108, 0, 101, 97, 98, 99, 94, 95,
	0, 0, 0, 0, 0, 0, 102, 0, 0, 0,
	0, 133, 100, 96, 111, 0, 103, 72, 13, 894,
	31, 59, 0, 0, 105, 87, 88, 89, 90, 91,
	0, 0, 0, 0, 73, 74, 0, 75, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 200, 201, 202, 203, 205, 206, 207, 208,
	209, 210, 211, 212, 204, 0, 0, 0, 0, 0,
	55, 56, 0, 0, 0, 0, 57, 0, 58, 53,
	54, 62, 63, 64, 65, 66, 67, 68, 70, 0,
	51, 84, 52, 213, 214, 0, 0, 24, 76, 77,
	0, 0, 0, 69, 46, 92, 93, 35, 0, 104,
	0, 26, 0, 0, 0, 109, 25, 17, 16, 0,
	18, 0, 29, 0, 30, 0, 0, 19, 0, 0,
	0, 20, 21, 34, 36, 0, 22, 32, 0, 0,
	33, 0, 0, 23, 0, 28, 85, 86, 316, 38,
	39, 40, 0, 0, 0, 50, 108, 0, 101, 97,
	98, 99, 94, 95, 0, 0, 0, 0, 0, 0,
	102, 0, 0, 0, 0, 133, 100, 96, 111, 0,
	103, 72, 13, 871, 31, 59, 0, 0, 105, 87,
	88, 89, 90, 91, 0, 0, 0, 0, 73, 74,
	0, 75, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 55, 56, 0, 0, 0, 0,
	57, 0, 58, 53, 54, 62, 63, 64, 65, 66,
	67, 68, 70, 0, 51, 84, 52, 0, 0, 0,
	0, 24, 76, 77, 0, 0, 0, 69, 46, 92,
	93, 35, 0, 104, 0, 26, 0, 0, 0, 109,
	25, 17, 16, 0, 18, 0, 29, 867, 30, 0,
	0, 19, 0, 0, 0, 20, 21, 34, 36, 0,
	22, 32, 0, 0, 33, 0, 0, 23, 0, 28,
	85, 86, 316, 38, 39, 40, 0, 0, 0, 50,
	108, 0, 101, 97, 98, 99, 94, 95, 0, 0,
	0, 0, 0, 0, 102, 0, 0, 0, 0, 133,
	100, 96, 111, 0, 103, 72, 13, 0, 31, 59,
	0, 0, 105, 87, 88, 89, 90, 91, 0, 0,
	0, 0, 73, 74, 0, 75, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 55, 56,
	0, 0, 0, 0, 57, 0, 58, 53, 54, 62,
	63, 64, 65, 66, 67, 68, 70, 0, 51, 84,
	52, 0, 0, 0, 0, 24, 76, 77, 0, 0,
	0, 69, 46, 92, 93, 35, 0, 104, 0, 26,
	0, 0, 0, 109, 25, 17, 16, 0, 18, 0,
	29, 0, 30, 787, 0, 19, 0, 0, 0, 20,
	21, 34, 36, 0, 22, 32, 0, 0, 33, 0,
	0, 23, 0, 28, 85, 86, 316, 38, 39, 40,
	0, 0, 0, 50, 108, 0, 101, 97, 98, 99,
	94, 95, 0, 0, 0, 0, 0, 0, 102, 0,
	0, 0, 0, 133, 100, 96, 111, 0, 103, 72,
	13, 0, 31, 59, 0, 0, 105, 87, 88, 89,
	90, 91, 0, 0, 0, 0, 73, 74, 0, 75,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 55, 56, 0, 0, 0, 0, 57, 0,
	58, 53, 54, 62, 63, 64, 65, 66, 67, 68,
	70, 0, 51, 84, 52, 0, 0, 0, 0, 24,
	76, 77, 0, 0, 0, 69, 46, 92, 93, 35,
	0, 104, 0, 26, 0, 0, 0, 109, 25, 17,
	16, 771, 18, 0, 29, 0, 30, 0, 0, 19,
	0, 0, 0, 20, 21, 34, 36, 0, 22, 32,
	0, 0, 33, 0, 0, 23, 0, 28, 85, 86,
	316, 38, 39, 40, 0, 0, 0, 50, 108, 0,
	101, 97, 98, 99, 94, 95, 0, 0, 0, 0,
	0, 0, 102, 0, 0, 0, 0, 133, 100, 96,
	111, 0, 103, 72, 13, 0, 31, 59, 0, 0,
	105, 87, 88, 89, 90, 91, 0, 0, 0, 0,
	73, 74, 0, 75, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 55, 56, 0, 0,
	0, 0, 57, 0, 58, 53, 54, 62, 63, 64,
	65, 66, 67, 68, 70, 0, 51, 84, 52, 0,
	0, 0, 694, 24, 76, 77, 0, 0, 0, 69,
	46, 92, 93, 35, 0, 104, 0, 26, 0, 0,
	0, 109, 25, 17, 16, 0, 18, 0, 29, 0,
	30, 0, 0, 19, 0, 0, 0, 20, 21, 34,
	36, 0, 22, 32, 0, 0, 33, 0, 0, 23,
	0, 28, 85, 86, 316, 38, 39, 40, 0, 0,
	0, 50, 108, 0, 101, 97, 98, 99, 94, 95,
	0, 0, 0, 0, 0, 0, 102, 0, 0, 0,
	0, 133, 100, 96, 111, 0, 103, 72, 13, 0,
	31, 59, 0, 0, 105, 87, 88, 89, 90, 91,
	0, 0, 0, 0, 73, 74, 0, 75, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	55, 56, 0, 0, 0, 0, 57, 0, 58, 53,
	54, 62, 63, 64, 65, 66, 67, 68, 70, 0,
	51, 84, 52, 0, 0, 0, 0, 24, 76, 77,
	0, 0, 0, 69, 46, 92, 93, 35, 0, 104,
	0, 26, 0, 0, 0, 109, 25, 17, 16, 0,
	18, 0, 29, 0, 30, 0, 0, 19, 0, 0,
	0, 20, 21, 34, 36, 0, 22, 32, 0, 0,
	33, 0, 0, 23, 0, 28, 85, 86, 316, 38,
	39, 40, 0, 0, 0, 50, 108, 0, 101, 97,
	98, 99, 94, 95, 0, 0, 0, 0, 0, 0,
	102, 0, 0, 0, 0, 133, 100, 96, 111, 0,
	103, 72, 13, 567, 31, 59, 0, 0, 105, 87,
	88, 89, 90, 91, 0, 0, 0, 0, 73, 74,
	0, 75, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 55, 56, 0, 0, 0, 0,
	57, 0, 58, 53, 54, 62, 63, 64, 65, 66,
	67, 68, 70, 0, 51, 84, 52, 0, 0, 0,
	0, 24, 76, 77, 0, 0, 0, 69, 46, 92,
	93, 35, 0, 104, 0, 26, 0, 0, 0, 109,
	25, 17, 16, 0, 18, 0, 29, 0, 30, 0,
	0, 19, 0, 0, 0, 20, 21, 34, 36, 0,
	22, 32, 0, 0, 33, 0, 0, 23, 0, 28,
	85, 86, 316, 38, 39, 40, 0, 0, 0, 50,
	108, 0, 101, 97, 98, 99, 94, 95, 0, 0,
	0, 0, 0, 0, 102, 0, 0, 0, 0, 133,
	100, 96, 111, 0, 103, 72, 13, 310, 31, 59,
	0, 0, 105, 87, 88, 89, 90, 91, 0, 0,
	0, 0, 73, 74, 0, 75, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 55, 56,
	0, 0, 0, 0, 57, 0, 58, 53, 54, 62,
	63, 64, 65, 66, 67, 68, 70, 0, 51, 84,
	52, 0, 0, 0, 0, 24, 76, 77, 0, 0,
	0, 69, 46, 92, 93, 35, 0, 104, 0, 26,
	0, 0, 0, 109, 25, 17, 16, 0, 18, 0,
	29, 0, 30, 0, 0, 19, 0, 0, 0, 20,
	21, 34, 36, 0, 22, 32, 0, 0, 33, 0,
	0, 23, 0, 28, 85, 86, 316, 38, 39, 40,
	0, 0, 0, 50, 108, 0, 101, 97, 98, 99,
	94, 95, 0, 0, 0, 0, 0, 0, 102, 0,
	0, 0, 0, 133, 100, 96, 111, 0, 103, 72,
	13, 0, 31, 59, 156, 155, 105, 441, 442, 443,
	444, 445, 0, 446, 447, 448, 484, 485, 0, 0,
	0, 0, 0, 179, 0, 180, 152, 153, 157, 159,
	158, 171, 172, 169, 170, 177, 173, 174, 175, 176,
	167, 168, 161, 162, 160, 163, 165, 166, 0, 178,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 449,
	0, 164, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 450, 451, 0, 454, 455, 456, 435,
	436, 437, 438, 439, 440, 452, 453, 0, 0, 432,
	0, 104, 0, 0, 0, 0, 0, 0, 457, 458,
	459, 460, 461, 462, 463, 464, 465, 466, 467, 487,
	488, 489, 490, 491, 479, 480, 481, 482, 483, 468,
	469, 470, 471, 472, 473, 474, 475, 476, 477, 478,
	0, 499, 497, 498, 494, 495, 0, 486, 492, 493,
	500, 501, 503, 502, 504, 505, 0, 0, 0, 0,
	0, 87, 88, 89, 90, 91, 0, 496, 507, 506,
	73, 74, 0, 75, 431, 0, 0, 0, 0, 0,
	105, 0, 0, 0, 0, 0, 0, 0, 783, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 55, 56, 0, 0,
	0, 0, 57, 0, 58, 53, 54, 62, 63, 64,
	65, 66, 67, 68, 70, 0, 51, 84, 52, 0,
	0, 0, 0, 24, 0, 0, 0, 0, 0, 69,
	46, 92, 93, 35, 0, 104, 0, 26, 0, 0,
	0, 109, 25, 17, 16, 0, 18, 0, 29, 0,
	30, 0, 0, 19, 0, 0, 0, 20, 21, 34,
	132, 0, 22, 32, 0, 0, 33, 0, 0, 23,
	0, 28, 85, 86, 0, 0, 0, 0, 0, 0,
	0, 50, 108, 0, 101, 97, 98, 99, 94, 95,
	0, 0, 0, 0, 0, 0, 102, 0, 0, 0,
	0, 133, 100, 96, 111, 0, 103, 72, 13, 0,
	31, 59, 0, 0, 105, 87, 88, 89, 90, 91,
	0, 0, 0, 0, 73, 74, 0, 75, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 862, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	55, 56, 0, 0, 0, 0, 57, 0, 58, 53,
	54, 62, 63, 64, 65, 66, 67, 68, 70, 0,
	51, 84, 52, 0, 0, 0, 0, 24, 0, 0,
	0, 0, 0, 69, 46, 92, 93, 35, 0, 104,
	0, 26, 0, 0, 0, 109, 25, 17, 16, 0,
	18, 0, 29, 0, 30, 0, 0, 19, 0, 0,
	0, 20, 21, 34, 132, 0, 22, 32, 0, 0,
	33, 0, 0, 23, 0, 28, 85, 86, 0, 0,
	0, 0, 0, 0, 0, 50, 108, 0, 101, 97,
	98, 99, 94, 95, 0, 0, 0, 0, 0, 0,
	102, 0, 0, 0, 0, 133, 100, 96, 111, 0,
	103, 72, 13, 0, 31, 59, 0, 0, 105, 87,
	88, 89, 90, 91, 0, 0, 0, 0, 73, 74,
	0, 75, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 696, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 55, 56, 0, 0, 0, 0,
	57, 0, 58, 53, 54, 62, 63, 64, 65, 66,
	67, 68, 70, 0, 51, 84, 52, 0, 0, 0,
	0, 24, 0, 0, 0, 0, 0, 69, 46, 92,
	93, 35, 0, 104, 0, 26, 0, 0, 0, 109,
	25, 17, 16, 0, 18, 0, 29, 0, 30, 0,
	0, 19, 0, 0, 0, 20, 21, 34, 132, 0,
	22, 32, 0, 0, 33, 0, 0, 23, 0, 28,
	85, 86, 0, 0, 0, 0, 0, 0, 0, 50,
	108, 0, 101, 97, 98, 99, 94, 95, 0, 0,
	0, 0, 0, 0, 102, 0, 0, 0, 0, 133,
	100, 96, 111, 0, 103, 72, 13, 0, 31, 59,
	0, 0, 105, 87, 88, 89, 90, 91, 0, 0,
	0, 0, 73, 74, 0, 75, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	665, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 55, 56,
	0, 0, 0, 0, 57, 0, 58, 53, 54, 62,
	63, 64, 65, 66, 67, 68, 70, 0, 51, 84,
	52, 0, 0, 0, 0, 24, 0, 0, 0, 0,
	0, 69, 46, 92, 93, 35, 0, 104, 0, 26,
	0, 0, 0, 109, 25, 17, 16, 0, 18, 0,
	29, 0, 30, 0, 0, 19, 0, 0, 0, 20,
	21, 34, 132, 0, 22, 32, 0, 0, 33, 0,
	0, 23, 0, 28, 85, 86, 0, 0, 0, 0,
	0, 0, 0, 50, 108, 0, 101, 97, 98, 99,
	94, 95, 0, 0, 0, 0, 0, 0, 102, 0,
	0, 0, 0, 133, 100, 96, 111, 0, 103, 72,
	13, 0, 31, 59, 0, 0, 105, 87, 88, 89,
	90, 91, 0, 0, 0, 0, 73, 74, 0, 75,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 647, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 55, 56, 0, 0, 0, 0, 57, 0,
	58, 53, 54, 62, 63, 64, 65, 66, 67, 68,
	70, 0, 51, 84, 52, 0, 0, 0, 0, 24,
	0, 0, 0, 0, 0, 69, 46, 92, 93, 35,
	0, 104, 0, 26, 0, 0, 0, 109, 25, 17,
	16, 0, 18, 0, 29, 0, 30, 0, 0, 19,
	0, 0, 0, 20, 21, 34, 132, 0, 22, 32,
	0, 0, 33, 0, 0, 23, 0, 28, 85, 86,
	0, 0, 0, 0, 0, 0, 0, 50, 108, 0,
	101, 97, 98, 99, 94, 95, 0, 0, 0, 0,
	0, 0, 102, 0, 0, 0, 0, 133, 100, 96,
	111, 0, 103, 72, 13, 155, 31, 59, 0, 0,
	105, 441, 442, 443, 444, 445, 0, 446, 447, 448,
	484, 485, 0, 179, 0, 180, 152, 153, 157, 159,
	158, 171, 172, 169, 170, 177, 173, 174, 175, 176,
	167, 168, 161, 162, 160, 163, 165, 166, 0, 178,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 164, 0, 449, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 450, 451, 0,
	454, 455, 456, 435, 436, 437, 438, 439, 440, 452,
	453, 0, 0, 857, 0, 0, 0, 0, 0, 0,
	0, 0, 457, 458, 459, 460, 461, 462, 463, 464,
	465, 466, 467, 487, 488, 489, 490, 491, 479, 480,
	481, 482, 483, 468, 469, 470, 471, 472, 473, 474,
	475, 476, 477, 478, 0, 499, 497, 498, 494, 495,
	0, 486, 492, 493, 500, 501, 503, 502, 504, 505,
	441, 442, 443, 444, 445, 426, 446, 447, 448, 484,
	485, 856, 507, 506, 111, 0, 0, 0, 0, 881,
	179, 0, 180, 152, 153, 157, 159, 158, 171, 172,
	169, 170, 177, 173, 174, 175, 176, 167, 168, 161,
	162, 160, 163, 165, 166, 0, 178, 0, 0, 0,
	0, 0, 449, 0, 0, 0, 0, 0, 164, 0,
	0, 0, 0, 0, 0, 0, 450, 451, 0, 454,
	455, 456, 435, 436, 437, 438, 439, 440, 452, 453,
	0, 0, 857, 0, 0, 0, 0, 0, 0, 0,
	0, 457, 458, 459, 460, 461, 462, 463, 464, 465,
	466, 467, 487, 488, 489, 490, 491, 479, 480, 481,
	482, 483, 468, 469, 470, 471, 472, 473, 474, 475,
	476, 477, 478, 0, 499, 497, 498, 494, 495, 0,
	486, 492, 493, 500, 501, 503, 502, 504, 505, 154,
	156, 155, 0, 0, 0, 87, 88, 89, 90, 91,
	856, 507, 506, 111, 73, 74, 0, 75, 847, 179,
	0, 180, 152, 153, 157, 159, 158, 171, 172, 169,
	170, 177, 173, 174, 175, 176, 167, 168, 161, 162,
	160, 163, 165, 166, 0, 178, 0, 0, 0, 0,
	55, 56, 0, 0, 0, 0, 57, 164, 58, 53,
	54, 62, 63, 64, 65, 66, 67, 68, 70, 0,
	51, 84, 52, 0, 0, 0, 0, 24, 0, 0,
	0, 0, 0, 69, 46, 92, 93, 35, 0, 104,
	0, 26, 0, 0, 0, 109, 25, 17, 16, 0,
	18, 0, 29, 0, 30, 0, 0, 19, 0, 0,
	0, 20, 21, 34, 132, 0, 22, 32, 0, 0,
	33, 0, 0, 23, 0, 28, 85, 86, 0, 0,
	0, 0, 0, 0, 0, 50, 108, 0, 101, 97,
	98, 99, 94, 95, 0, 0, 0, 0, 0, 0,
	102, 0, 0, 0, 693, 133, 100, 96, 111, 0,
	103, 72, 13, 0, 31, 59, 0, 0, 105, 441,
	442, 443, 444, 445, 0, 446, 447, 448, 484, 485,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 449, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 450, 451, 0, 454, 455,
	456, 435, 436, 437, 438, 439, 440, 452, 453, 0,
	0, 432, 0, 0, 0, 0, 0, 0, 0, 0,
	457, 458, 459, 460, 461, 462, 463, 464, 465, 466,
	467, 487, 488, 489, 490, 491, 479, 480, 481, 482,
	483, 468, 469, 470, 471, 472, 473, 474, 475, 476,
	477, 478, 0, 499, 497, 498, 494, 495, 0, 486,
	492, 493, 500, 501, 503, 502, 504, 505, 441, 442,
	443, 444, 445, 0, 446, 447, 448, 484, 485, 496,
	507, 506, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	449, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 450, 451, 0, 454, 455, 456,
	687, 688, 689, 686, 685, 684, 452, 453, 0, 0,
	899, 0, 0, 0, 0, 0, 0, 0, 0, 457,
	458, 459, 460, 461, 462, 463, 464, 465, 466, 467,
	487, 488, 489, 490, 491, 479, 480, 481, 482, 483,
	468, 469, 470, 471, 472, 473, 474, 475, 476, 477,
	478, 0, 499, 497, 498, 494, 495, 0, 486, 492,
	493, 500, 501, 503, 502, 504, 505, 0, 0, 0,
	233, 0, 87, 88, 89, 90, 91, 232, 496, 507,
	506, 73, 74, 0, 75, 0, 0, 116, 0, 104,
	0, 0, 0, 0, 0, 109, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 55, 56, 0,
	0, 0, 0, 57, 0, 58, 53, 54, 62, 63,
	64, 65, 66, 67, 68, 70, 108, 51, 84, 52,
	0, 0, 0, 0, 138, 0, 0, 0, 0, 0,
	69, 0, 92, 93, 116, 133, 104, 0, 111, 0,
	0, 0, 109, 0, 0, 230, 0, 0, 105, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 132, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 85, 86, 0, 0, 0, 0, 0,
	0, 0, 50, 108, 0, 101, 97, 98, 99, 94,
	95, 0, 0, 0, 0, 0, 0, 102, 0, 0,
	0, 0, 133, 100, 96, 111, 532, 103, 72, 0,
	0, 0, 59, 528, 0, 105, 87, 88, 89, 90,
	91, 0, 0, 0, 0, 73, 74, 0, 75, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 225,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 55, 56, 0, 0, 0, 0, 57, 0, 58,
	53, 54, 62, 63, 64, 65, 66, 67, 68, 70,
	0, 51, 84, 52, 0, 0, 0, 0, 138, 0,
	0, 0, 0, 0, 69, 0, 92, 93, 116, 0,
	104, 0, 0, 0, 0, 0, 109, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 132, 0, 0, 0, 0,
	0, 0, 87, 88, 89, 90, 91, 85, 86, 0,
	0, 73, 74, 0, 75, 0, 226, 108, 0, 101,
	97, 98, 99, 94, 95, 0, 0, 0, 0, 0,
	0, 102, 0, 0, 0, 0, 133, 100, 96, 111,
	0, 103, 72, 0, 0, 0, 59, 55, 56, 105,
	0, 0, 0, 57, 0, 58, 53, 54, 62, 63,
	64, 65, 66, 67, 68, 70, 0, 51, 84, 52,
	0, 0, 0, 0, 138, 0, 0, 0, 0, 0,
	69, 0, 92, 93, 116, 0, 104, 0, 0, 0,
	0, 0, 109, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 132, 0, 0, 0, 0, 0, 0, 87, 88,
	89, 90, 91, 85, 86, 0, 0, 73, 74, 0,
	75, 0, 50, 108, 0, 101, 97, 98, 99, 94,
	95, 0, 0, 0, 0, 0, 0, 102, 0, 0,
	0, 600, 133, 100, 96, 111, 532, 103, 72, 0,
	0, 0, 59, 55, 56, 105, 0, 0, 0, 57,
	0, 58, 53, 54, 62, 63, 64, 65, 66, 67,
	68, 70, 0, 51, 84, 52, 0, 0, 0, 0,
	138, 0, 0, 0, 0, 0, 69, 0, 92, 93,
	116, 0, 104, 0, 0, 0, 0, 0, 109, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 132, 0, 0,
	0, 0, 0, 0, 87, 88, 89, 90, 91, 85,
	86, 0, 0, 73, 74, 0, 75, 0, 601, 108,
	0, 101, 97, 98, 99, 94, 95, 0, 0, 0,
	0, 0, 0, 102, 0, 0, 0, 0, 133, 100,
	96, 111, 0, 103, 72, 0, 0, 0, 59, 55,
	56, 105, 0, 0, 0, 57, 0, 58, 53, 54,
	62, 63, 64, 65, 66, 67, 68, 70, 0, 51,
	84, 52, 0, 0, 0, 0, 138, 0, 0, 0,
	0, 0, 69, 0, 92, 93, 116, 424, 104, 0,
	0, 0, 0, 0, 109, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 132, 0, 0, 0, 0, 0, 0,
	87, 88, 89, 90, 91, 85, 86, 0, 0, 73,
	74, 0, 75, 0, 50, 108, 0, 101, 97, 98,
	99, 94, 95, 0, 0, 0, 0, 0, 0, 102,
	0, 0, 0, 387, 133, 100, 96, 111, 0, 103,
	72, 0, 0, 0, 59, 55, 56, 105, 0, 0,
	0, 57, 0, 58, 53, 54, 62, 63, 64, 65,
	66, 67, 68, 70, 0, 51, 84, 52, 0, 0,
	0, 0, 138, 0, 0, 0, 0, 0, 69, 0,
	92, 93, 116, 0, 104, 0, 0, 0, 0, 0,
	109, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 132,
	0, 0, 0, 0, 0, 0, 87, 88, 89, 90,
	91, 85, 86, 0, 0, 73, 74, 0, 75, 0,
	50, 108, 0, 101, 97, 98, 99, 94, 95, 0,
	0, 0, 0, 363, 0, 102, 0, 0, 0, 0,
	133, 100, 96, 111, 0, 103, 72, 0, 0, 0,
	59, 55, 56, 105, 0, 0, 0, 57, 0, 58,
	53, 54, 62, 63, 64, 65, 66, 67, 68, 70,
	0, 51, 84, 52, 0, 0, 0, 0, 138, 0,
	0, 0, 0, 0, 69, 0, 92, 93, 116, 0,
	104, 0, 0, 0, 0, 0, 109, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 132, 0, 0, 0, 0,
	0, 0, 87, 88, 89, 90, 91, 85, 86, 0,
	0, 73, 74, 0, 75, 0, 50, 108, 0, 101,
	97, 98, 99, 94, 95, 0, 0, 0, 0, 0,
	0, 102, 0, 0, 0, 0, 133, 100, 96, 111,
	0, 103, 72, 0, 0, 0, 59, 55, 56, 105,
	0, 0, 0, 57, 0, 58, 53, 54, 62, 63,
	64, 65, 66, 67, 68, 70, 0, 51, 84, 52,
	0, 0, 0, 0, 138, 0, 0, 0, 0, 0,
	69, 0, 92, 93, 116, 0, 104, 0, 0, 0,
	0, 0, 109, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 132, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 85, 86, 0, 0, 0, 0, 0,
	0, 0, 50, 108, 0, 101, 97, 98, 99, 94,
	95, 0, 0, 0, 154, 156, 155, 102, 0, 0,
	0, 0, 133, 100, 96, 111, 0, 103, 72, 0,
	0, 0, 59, 0, 179, 105, 180, 152, 153, 157,
	159, 158, 171, 172, 169, 170, 177, 173, 174, 175,
	176, 167, 168, 161, 162, 160, 163, 165, 166, 0,
	178, 154, 156, 155, 0, 0, 0, 0, 0, 0,
	0, 0, 164, 0, 0, 0, 0, 0, 0, 0,
	0, 179, 0, 180, 152, 153, 157, 159, 158, 171,
	172, 169, 170, 177, 173, 174, 175, 176, 167, 168,
	161, 162, 160, 163, 165, 166, 0, 178, 154, 156,
	155, 0, 0, 0, 0, 0, 0, 0, 0, 164,
	0, 0, 0, 0, 0, 0, 0, 0, 179, 0,
	180, 152, 153, 157, 159, 158, 171, 172, 169, 170,
	177, 173, 174, 175, 176, 167, 168, 161, 162, 160,
	163, 165, 166, 0, 178, 154, 156, 155, 0, 0,
	0, 0, 0, 0, 0, 0, 164, 0, 0, 0,
	763, 0, 0, 0, 0, 179, 0, 180, 152, 153,
	157, 159, 158, 171, 172, 169, 170, 177, 173, 174,
	175, 176, 167, 168, 161, 162, 160, 163, 165, 166,
	0, 178, 154, 156, 155, 0, 0, 0, 0, 0,
	0, 0, 0, 164, 0, 0, 692, 0, 0, 0,
	0, 0, 179, 0, 180, 152, 153, 157, 159, 158,
	171, 172, 169, 170, 177, 173, 174, 175, 176, 167,
	168, 161, 162, 160, 163, 165, 166, 0, 178, 154,
	156, 155, 0, 0, 0, 0, 0, 0, 0, 0,
	164, 0, 0, 630, 0, 0, 0, 0, 0, 179,
	0, 180, 152, 153, 157, 159, 158, 171, 172, 169,
	170, 177, 173, 174, 175, 176, 167, 168, 161, 162,
	160, 163, 165, 166, 0, 178, 154, 156, 155, 0,
	0, 0, 0, 0, 0, 0, 0, 164, 0, 0,
	629, 0, 0, 0, 0, 0, 179, 0, 180, 152,
	153, 157, 159, 158, 171, 172, 169, 170, 177, 173,
	174, 175, 176, 167, 168, 161, 162, 160, 163, 165,
	166, 0, 178, 154, 156, 155, 0, 0, 0, 0,
	0, 0, 0, 0, 164, 0, 0, 603, 0, 0,
	0, 0, 0, 179, 0, 180, 152, 153, 157, 159,
	158, 171, 172, 169, 170, 177, 173, 174, 175, 176,
	167, 168, 161, 162, 160, 163, 165, 166, 0, 178,
	154, 156, 155, 0, 0, 0, 0, 0, 0, 0,
	0, 164, 0, 0, 591, 0, 0, 0, 0, 0,
	179, 0, 180, 152, 153, 157, 159, 158, 171, 172,
	169, 170, 177, 173, 174, 175, 176, 167, 168, 161,
	162, 160, 163, 165, 166, 0, 178, 154, 156, 155,
	0, 0, 0, 0, 0, 0, 0, 0, 164, 0,
	0, 555, 0, 0, 0, 0, 0, 179, 819, 180,
	152, 153, 157, 159, 158, 171, 172, 169, 170, 177,
	173, 174, 175, 176, 167, 168, 161, 162, 160, 163,
	165, 166, 0, 178, 154, 156, 155, 0, 0, 0,
	0, 0, 0, 0, 0, 164, 0, 0, 551, 0,
	0, 0, 0, 0, 179, 0, 180, 152, 153, 157,
	159, 158, 171, 172, 169, 170, 177, 173, 174, 175,
	176, 167, 168, 161, 162, 160, 163, 165, 166, 0,
	178, 154, 156, 155, 0, 0, 0, 0, 0, 0,
	0, 0, 164, 0, 0, 415, 0, 0, 0, 0,
	0, 179, 0, 180, 152, 153, 157, 159, 158, 171,
	172, 169, 170, 177, 173, 174, 175, 176, 167, 168,
	161, 162, 160, 163, 165, 166, 0, 178, 154, 156,
	155, 0, 0, 0, 0, 0, 0, 0, 0, 164,
	820, 0, 0, 0, 0, 0, 0, 0, 179, 0,
	180, 152, 153, 157, 159, 158, 171, 172, 169, 170,
	177, 173, 174, 175, 176, 167, 168, 161, 162, 160,
	163, 165, 166, 0, 178, 154, 156, 155, 0, 0,
	0, 0, 0, 0, 0, 0, 164, 371, 0, 0,
	0, 0, 0, 0, 0, 179, 0, 180, 152, 153,
	157, 159, 158, 171, 172, 169, 170, 177, 173, 174,
	175, 176, 167, 168, 161, 162, 160, 163, 165, 166,
	0, 178, 0, 154, 156, 155, 0, 0, 0, 0,
	0, 0, 0, 164, 151, 0, 0, 0, 0, 0,
	0, 0, 0, 179, 0, 180, 152, 153, 157, 159,
	158, 171, 172, 169, 170, 177, 173, 174, 175, 176,
	167, 168, 161, 162, 160, 163, 165, 166, 0, 178,
	154, 156, 155, 0, 0, 0, 0, 0, 0, 0,
	708, 164, 0, 0, 0, 0, 0, 0, 0, 0,
	179, 0, 180, 152, 153, 157, 159, 158, 171, 172,
	169, 170, 177, 173, 174, 175, 176, 167, 168, 161,
	162, 160, 163, 165, 166, 0, 178, 0, 154, 156,
	155, 0, 0, 0, 0, 0, 0, 706, 164, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 179, 0,
	180, 152, 153, 157, 159, 158, 171, 172, 169, 170,
	177, 173, 174, 175, 176, 167, 168, 161, 162, 160,
	163, 165, 166, 0, 178, 154, 156, 155, 0, 0,
	0, 0, 0, 0, 0, 697, 164, 0, 0, 0,
	0, 0, 0, 0, 0, 179, 0, 180, 152, 153,
	157, 159, 158, 171, 172, 169, 170, 177, 173, 174,
	175, 176, 167, 168, 161, 162, 160, 163, 165, 166,
	0, 178, 0, 154, 156, 155, 0, 0, 0, 0,
	0, 0, 631, 164, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 179, 0, 180, 152, 153, 157, 159,
	158, 171, 172, 169, 170, 177, 173, 174, 175, 176,
	167, 168, 161, 162, 160, 163, 165, 166, 0, 178,
	154, 156, 155, 0, 0, 0, 0, 0, 0, 0,
	612, 164, 0, 0, 0, 0, 0, 0, 0, 0,
	179, 561, 180, 152, 153, 157, 159, 158, 171, 172,
	169, 170, 177, 173, 174, 175, 176, 167, 168, 161,
	162, 160, 163, 165, 166, 0, 178, 0, 565, 154,
	156, 155, 0, 0, 410, 0, 0, 593, 164, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 179,
	0, 180, 152, 153, 157, 159, 158, 171, 172, 169,
	170, 177, 173, 174, 175, 176, 167, 168, 161, 162,
	160, 163, 165, 166, 0, 178, 154, 156, 155, 0,
	0, 0, 0, 0, 0, 0, 0, 164, 0, 0,
	0, 0, 0, 0, 0, 0, 179, 0, 180, 152,
	153, 157, 159, 158, 171, 172, 169, 170, 177, 173,
	174, 175, 176, 167, 168, 161, 162, 160, 163, 165,
	166, 0, 178, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 164,
}
var yyPact = [...]int{

	-1000, -1000, 1193, -1000, -1000, -1000, -1000, -1000, -1000, 150,
	251, 421, 516, -1000, -1000, -1000, 149, 4901, 146, 144,
	6208, 6208, 6208, 20, 452, 6208, -1000, 6861, 143, 141,
	138, -1000, 259, 6208, 595, 709, 660, 573, 590, 571,
	568, 615, 688, 2355, -1000, -1000, 134, -1000, -1000, 302,
	132, 5512, 6208, 5281, 5281, 6208, 6208, 6208, 6208, 6208,
	-1000, -1000, 6208, 6208, 6208, 6208, 6208, 6208, 6208, 131,
	6208, -1000, 645, 6208, 6208, 6208, -1000, -1000, -1000, 614,
	-1000, 361, 301, -1000, 172, 128, 105, 6208, 6208, 95,
	6208, 6208, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, 567, 553, -1000, 33, 66, 66, 83, -1000,
	272, 498, -22, 498, -12, -1000, -1000, 207, 451, 292,
	442, 498, -1000, -1000, -1000, -1000, 290, -1000, 752, 3325,
	6208, 453, 660, 271, 6208, 6208, 206, 7336, 423, 204,
	203, 276, -1000, -1000, 267, 660, -1000, 747, 261, -1000,
	7336, -1000, 6208, 6208, 6208, 6208, 6208, 6208, 6208, 6208,
	6208, 6208, 6208, 6208, 6208, 6208, 6208, 6208, 6208, 6208,
	6208, 6208, 6208, 6208, 6208, 6208, 6208, 6208, 31, 6092,
	6208, 5281, 6208, 516, -1000, 6814, 199, -1000, 58, -1000,
	566, -1000, 390, 258, 392, 82, 4901, 78, 197, 699,
	5976, 6208, 6208, 6208, 6208, 6208, 6208, 6208, 6208, 6208,
	6208, 6208, 6208, -1000, -1000, 6208, 6208, 6208, 96, 5512,
	-53, 780, -1000, -1000, 7289, 5281, 77, -1000, -1000, 614,
	6208, -1000, -1000, 5512, -1000, 577, 577, 644, 577, 6720,
	577, 577, 577, 577, 577, 577, 577, -1000, 6208, 577,
	262, 454, 458, -1000, 456, 5860, 5281, 1014, 4750, 1014,
	6208, 3653, 3653, 66, -1000, 284, 198, 66, -1000, -1000,
	6208, 6208, 7336, 7336, 6208, 7336, 7336, 576, -1000, 540,
	368, 454, 6208, -1000, -1000, 5348, -1000, 5512, 561, 272,
	195, 272, -1000, -1000, 1029, -1000, 193, 235, 438, 498,
	-1000, 365, 352, 525, 434, -1000, -1000, 516, 6208, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, 76, 6673, 75, 74,
	189, 777, 7336, 6626, -1000, -1000, -1000, -1000, 20, -1000,
	487, 69, 6208, -1000, 6208, 1340, 1504, 3643, 1014, 4603,
	1668, 1992, 1829, 845, 845, 845, 644, 577, 644, 644,
	1287, 1287, 2151, 2151, 2151, 2151, 775, 775, 775, 775,
	2151, -1000, 7240, 6208, 1178, 772, -1000, -1000, 7193, 103,
	3161, -1000, -1000, 68, 539, 390, 385, 354, -1000, 256,
	354, 6208, -1000, 6208, -1000, -1000, 1014, 6208, 1014, 1014,
	1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014, 1014,
	6579, -61, 7145, 66, -1000, 6208, -1000, -24, 740, 5512,
	5744, -1000, 5512, 6532, -62, -1000, -27, -1000, -1000, -1000,
	-1000, 679, 507, 7098, 279, 231, 6208, -66, 66, -1000,
	-1000, 6208, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000, 66, -1000,
	-1000, -1000, -1000, 20, 6208, 6208, 96, 20, 390, 769,
	-1000, 7336, 6485, 6438, -1000, -1000, -1000, 7050, -1000, 768,
	-1000, 7336, 6208, -31, -1000, -1000, 865, -1000, -1000, -1000,
	348, 413, -1000, 498, 353, 623, -1000, 332, -1000, 7336,
	-32, 4453, 6208, 6208, 6208, 330, -1000, -1000, 539, 7336,
	-1000, 6208, 1178, -33, 5281, 269, 4289, -1000, 539, -35,
	763, -1000, 673, -1000, -1000, 446, -1000, -1000, -1000, 385,
	253, 354, -1000, 559, -1000, 745, -1000, 6391, 4889, 2997,
	1992, 4125, -1000, -1000, -1000, 7003, 724, 6208, -1000, 7336,
	5281, 64, -36, -1000, -1000, -1000, -70, -1000, -1000, 463,
	-1000, -1000, -1000, -1000, 6208, -1000, 1014, -1000, -1000, 6955,
	-1000, -1000, -73, 6908, -1000, -1000, 385, -37, 6208, -1000,
	-1000, -1000, -38, 5628, 7336, -1000, -1000, 498, 329, 762,
	-1000, -1000, 498, 623, 184, -1000, -1000, -1000, 432, 180,
	7336, -1000, 179, 178, -39, 1178, 177, -1000, 80, -1000,
	5281, 61, 5512, -1000, -1000, -1000, 412, -40, 408, 539,
	263, -1000, -1000, 248, -1000, 745, -1000, -1000, 470, 509,
	354, 737, -1000, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	425, 354, 4901, 692, 171, -1000, -1000, -1000, 6208, 1014,
	-1000, 5512, 724, -1000, -1000, 6344, -1000, -1000, -1000, 246,
	-1000, -1000, -1000, -1000, 761, -1000, 498, 229, 623, -1000,
	762, -1000, 2833, 164, 6208, 127, -1000, 535, -1000, 408,
	-1000, 3797, 269, -1000, 5512, -79, 2669, -1000, 59, 244,
	682, 682, 51, -1000, 475, -1000, -1000, 418, 205, -1000,
	738, 5065, 660, 130, -1000, -1000, -1000, -1000, -1000, -1000,
	3489, 1014, -41, 228, -1000, 223, 498, 761, -1000, -1000,
	218, 162, -1000, -42, -1000, 6208, 121, 118, 161, 523,
	682, -1000, -1000, -1000, -43, -45, -1000, 158, 354, -1000,
	241, 539, 239, 643, 732, 369, -1000, -1000, 470, 6208,
	190, -1000, 726, 5065, -1000, -1000, 4756, 3489, 724, -1000,
	174, -1000, -1000, 211, -1000, -1000, 3961, 6767, -1000, -1000,
	-1000, -1000, -1000, 157, 238, 2505, 3797, -1000, -1000, 536,
	-1000, 2341, -1000, -1000, -1000, 97, -1000, -1000, 468, 6208,
	-1000, -1000, 7336, -1000, 5065, 6208, 25, -1000, 4617, -1000,
	156, 154, 403, 439, 278, -1000, 271, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, 3489, -1000, -1000, 153, -1000, -47,
	354, -1000, 2177, 2013, -1000, 643, -1000, 7336, -1000, 7336,
	539, -1000, -1000, -1000, -1000, 354, 5204, 5065, 1849, 3489,
	1685, -1000, 233, -1000, -1000, -1000, -1000, -51, 745, -1000,
	-1000, 5065, -1000, 32, -1000, -1000, 682, -1000, -1000, 1521,
	-15, -1000, -1000, -1000, -1000, 1357, -1000,
}
var yyPgo = [...]int{

	0, 940, 939, 46, 686, 6, 938, 3, 937, 14,
	27, 79, 77, 70, 51, 933, 921, 20, 919, 94,
	15, 78, 918, 0, 62, 917, 912, 17, 11, 911,
	910, 36, 61, 49, 33, 908, 35, 906, 72, 50,
	904, 9, 903, 902, 896, 894, 13, 48, 889, 887,
	111, 98, 197, 886, 883, 882, 8, 880, 81, 43,
	877, 55, 47, 876, 875, 874, 867, 866, 97, 862,
	861, 103, 1, 860, 859, 7, 19, 38, 857, 856,
	83, 853, 10, 4, 851, 86, 850, 18, 849, 848,
	847, 44, 42, 32, 41, 2, 16, 845, 842, 841,
	5, 775, 839, 670, 837, 28, 835, 833, 832, 90,
	819, 31, 811, 809, 25, 29, 804, 802, 801, 24,
	798, 793, 792, 549, 790, 37, 12,
}
var yyR1 = [...]int{

	0, 124, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5, 5, 6,
	6, 6, 6, 6, 6, 6, 7, 7, 71, 71,
	105, 105, 9, 9, 9, 8, 8, 8, 8, 8,
	8, 8, 8, 8, 8, 8, 8, 8, 8, 101,
	101, 16, 16, 18, 18, 125, 125, 115, 115, 114,
	114, 123, 123, 17, 17, 20, 20, 19, 19, 109,
	109, 72, 72, 22, 22, 22, 22, 22, 22, 10,
	10, 10, 10, 10, 10, 10, 10, 10, 10, 10,
	10, 10, 10, 10, 10, 10, 10, 10, 10, 10,
	10, 10, 10, 107, 107, 106, 106, 30, 30, 122,
	122, 31, 11, 1, 1, 2, 2, 12, 12, 102,
	102, 4, 4, 13, 14, 33, 33, 15, 15, 77,
	77, 27, 27, 27, 27, 26, 26, 28, 28, 29,
	29, 118, 118, 118, 118, 119, 119, 119, 126, 126,
	25, 25, 78, 78, 73, 73, 86, 86, 74, 74,
	75, 75, 79, 79, 34, 34, 35, 35, 96, 96,
	94, 94, 94, 95, 95, 80, 80, 81, 81, 36,
	36, 113, 113, 38, 117, 117, 39, 39, 76, 76,
	40, 40, 40, 40, 83, 83, 121, 121, 121, 120,
	120, 41, 41, 42, 43, 43, 43, 43, 45, 45,
	44, 84, 84, 97, 97, 98, 98, 99, 99, 100,
	100, 100, 100, 100, 100, 116, 116, 46, 46, 108,
	108, 82, 21, 110, 110, 47, 111, 111, 112, 112,
	49, 48, 48, 37, 37, 37, 37, 37, 37, 37,
	37, 37, 37, 37, 37, 37, 37, 37, 37, 37,
	37, 37, 37, 37, 37, 37, 37, 37, 37, 37,
	37, 37, 37, 37, 37, 37, 37, 37, 37, 37,
	37, 37, 37, 37, 37, 37, 37, 37, 37, 37,
	37, 37, 37, 37, 37, 37, 37, 37, 37, 37,
	37, 37, 37, 37, 37, 37, 37, 37, 37, 37,
	37, 37, 37, 37, 37, 37, 37, 37, 37, 3,
	3, 87, 87, 88, 88, 56, 56, 57, 57, 57,
	57, 50, 50, 51, 51, 54, 54, 104, 104, 104,
	85, 85, 61, 61, 61, 55, 55, 55, 55, 55,
	55, 55, 55, 55, 55, 55, 55, 55, 55, 55,
	55, 62, 62, 62, 23, 23, 24, 24, 60, 63,
	63, 63, 64, 64, 64, 65, 65, 65, 65, 65,
	65, 32, 32, 32, 52, 52, 52, 66, 66, 67,
	67, 67, 67, 67, 67, 58, 58, 58, 59, 59,
	59, 91, 92, 92, 90, 90, 89, 89, 89, 89,
	89, 89, 103, 103, 103, 103, 68, 68, 68, 68,
	68, 68, 68, 69, 69, 69, 69, 53, 53, 53,
	53, 53, 53, 53, 70, 70, 93,
}
var yyR2 = [...]int{

	0, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1, 2, 0,
	1, 3, 1, 3, 2, 1, 1, 1, 1, 1,
	4, 3, 5, 4, 3, 4, 3, 4, 3, 1,
	1, 6, 7, 6, 7, 0, 1, 3, 1, 3,
	1, 3, 1, 1, 2, 1, 3, 1, 2, 3,
	1, 2, 0, 1, 1, 1, 1, 1, 4, 3,
	1, 1, 5, 7, 9, 5, 3, 3, 3, 3,
	3, 3, 1, 2, 6, 7, 9, 5, 1, 6,
	3, 3, 2, 0, 9, 1, 3, 0, 4, 1,
	3, 1, 10, 0, 1, 0, 1, 8, 7, 1,
	2, 1, 1, 5, 6, 0, 2, 0, 2, 0,
	2, 1, 2, 4, 3, 1, 4, 1, 4, 1,
	4, 3, 4, 4, 5, 0, 5, 4, 1, 1,
	1, 4, 5, 6, 1, 3, 6, 7, 3, 6,
	1, 0, 1, 3, 4, 6, 0, 1, 1, 2,
	1, 1, 1, 0, 2, 2, 4, 1, 3, 1,
	2, 3, 1, 1, 3, 1, 1, 3, 2, 0,
	3, 4, 3, 9, 1, 3, 1, 2, 3, 1,
	2, 2, 2, 3, 3, 3, 4, 3, 1, 1,
	3, 1, 3, 1, 1, 0, 1, 1, 2, 1,
	1, 1, 1, 1, 1, 3, 1, 1, 3, 3,
	1, 3, 3, 3, 1, 1, 0, 1, 3, 1,
	7, 3, 2, 6, 5, 3, 4, 2, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	2, 2, 2, 2, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 2, 2, 2, 2, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 1, 5, 4, 3,
	1, 2, 2, 2, 2, 2, 2, 2, 2, 2,
	1, 3, 2, 1, 2, 4, 2, 10, 11, 0,
	1, 0, 4, 3, 1, 1, 2, 2, 4, 4,
	2, 1, 1, 1, 1, 0, 3, 0, 1, 1,
	0, 1, 4, 3, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 3, 2, 3, 3, 1,
	1, 1, 3, 3, 1, 1, 0, 1, 1, 1,
	3, 1, 1, 3, 1, 1, 4, 4, 4, 4,
	1, 1, 1, 3, 1, 4, 2, 3, 3, 1,
	4, 4, 3, 3, 3, 1, 3, 1, 1, 3,
	1, 1, 0, 1, 3, 1, 3, 1, 4, 2,
	6, 4, 2, 2, 1, 2, 1, 4, 3, 3,
	3, 6, 3, 1, 1, 2, 1, 5, 4, 2,
	2, 4, 2, 2, 1, 3, 1,
}
var yyChk = [...]int{

	-1000, -124, -71, -8, -10, -11, -12, -13, -14, 127,
	154, 120, 114, 161, -73, -74, 97, 96, 99, 106,
	110, 111, 115, 122, 76, 95, 90, -23, 124, 101,
	103, 163, 116, 119, 112, 86, 113, -102, 128, 129,
	130, -78, -86, -32, -37, -4, 83, -65, -66, -63,
	134, 69, 71, 58, 59, 49, 50, 55, 57, 164,
	-48, -53, 60, 61, 62, 63, 64, 65, 66, 82,
	67, -55, 160, 13, 14, 16, 77, 78, -52, -62,
	-57, -50, -60, -61, 70, 125, 126, 4, 5, 6,
	7, 8, 84, 85, 141, 142, 156, 138, 139, 140,
	155, 137, 149, 159, 88, 167, -9, -64, 135, 94,
	-105, 157, 164, 157, -105, 161, 86, -18, -101, -123,
	-105, 157, 113, 114, -19, -20, -109, -21, 86, -72,
	164, -10, 113, 154, 164, 164, -24, -23, 76, -24,
	-24, -113, -38, -52, -117, 113, -39, 88, -110, -47,
	-23, 163, 33, 34, 10, 12, 11, 35, 37, 36,
	51, 49, 50, 52, 68, 53, 54, 47, 48, 40,
	41, 38, 39, 43, 44, 45, 46, 42, 56, 30,
	32, 164, 164, 164, 161, -23, 86, 31, -3, 37,
	128, -4, 86, 86, 86, 73, 74, 73, 75, 74,
	17, 18, 19, 20, 29, 21, 22, 23, 24, 25,
	26, 27, 28, 58, 59, 164, 69, 161, 133, 164,
	-91, -90, -92, -89, -23, 37, 134, -23, -32, -62,
	164, -61, 76, 69, -32, -23, -23, -23, -23, -23,
	-23, -23, -23, -23, -23, -23, -23, -54, 164, -23,
	-104, 93, -103, -68, 88, 151, 152, -23, -23, -23,
	69, 153, 153, -51, -49, -50, -67, 128, -9, -52,
	164, 164, -23, -23, 164, -23, -23, 93, 150, -103,
	-103, 93, 161, -52, -80, 164, -80, 164, 157, -105,
	165, -105, 163, 161, -71, 163, -16, -123, -105, 157,
	163, 9, 157, 105, -105, -20, 163, 9, 17, -22,
	162, -10, -11, -12, -13, -14, 127, -23, 97, -3,
	-111, -112, -23, -23, 163, 163, 163, 163, 9, 163,
	9, -3, 17, 163, 9, -23, -23, -23, -23, -23,
	-23, -23, -23, -23, -23, -23, -23, -23, -23, -23,
	-23, -23, -23, -23, -23, -23, -23, -23, -23, -23,
	-23, -51, -23, 31, -23, -122, -31, -32, -23, -109,
	-72, 163, 163, 86, 164, 86, -33, 131, 161, -15,
	131, 164, -10, 164, 163, 31, -23, 37, -23, -23,
	-23, -23, -23, -23, -23, -23, -23, -23, -23, -23,
	-23, -24, -23, -59, 86, 161, -52, -91, 166, 9,
	15, -32, 164, -23, -91, 165, -24, 160, -68, -68,
	93, 69, 133, -23, 87, -32, 15, -24, -58, -7,
	-52, 161, 86, -6, -5, 76, 77, 78, 79, 80,
	81, 4, 5, 6, 7, 8, 10, 11, 12, 56,
	70, 71, 82, 83, 73, 74, 75, 95, 96, 97,
	98, 99, 100, 101, 102, 103, 104, 105, 116, 117,
	118, 119, 120, 121, 122, 123, 124, 125, 126, 111,
	112, 113, 114, 115, 13, 14, 134, 106, 107, 108,
	109, 110, 135, 136, 131, 132, 154, 129, 130, 128,
	137, 138, 140, 139, 141, 142, 156, 155, -58, -7,
	-52, -85, -80, 153, 69, 161, 133, 153, -85, -70,
	-93, -23, -23, -23, 150, 150, 159, -23, 165, -81,
	-36, -23, 158, -91, 86, 163, -71, 162, 163, 163,
	157, -105, -19, 157, -105, 161, 86, 157, -21, -23,
	164, 165, 164, 163, 9, 165, -38, -39, 164, -23,
	-47, 31, -23, -125, 9, 105, 165, 162, 164, -75,
	-79, -34, -35, -96, -94, 30, 135, 136, -9, -33,
	-77, 132, -9, -76, 161, -83, -9, -23, -23, -72,
	-23, 165, 166, 162, -80, -23, 165, 17, -92, -23,
	37, 134, -91, 165, 166, 165, -69, 86, 89, 50,
	88, 86, 162, 162, 69, 162, -23, 166, -80, -23,
	-80, -52, -24, -23, -59, -52, -33, -125, 9, 165,
	165, 162, -125, 9, -23, 165, 162, 161, 157, -115,
	-17, -20, -101, 161, 165, -25, -10, 31, -23, -111,
	-23, -118, 161, 31, -75, -23, 165, -31, -27, -32,
	37, 134, 69, -29, -10, 31, -107, -75, 165, 9,
	-1, 37, -94, -77, 161, -83, 162, -40, -97, -98,
	120, -99, 123, -100, 81, 80, 79, 76, 77, 78,
	-76, 9, 165, 165, 75, -10, 31, 162, 17, -23,
	-32, 164, 165, 166, 89, -23, 162, 166, 162, -77,
	165, -93, 165, -36, -114, -20, 161, -125, 9, -20,
	-115, 163, -72, 165, 163, -119, 163, -119, 163, 165,
	163, 165, 15, -32, 164, -91, -72, -30, 117, 118,
	165, -87, 120, -34, -2, 158, 161, -76, -116, -46,
	88, 114, 113, -83, -100, 162, -9, -10, 31, 163,
	-72, -23, -91, 166, 161, -125, 9, -114, 162, -17,
	-125, 98, 163, -111, 162, 108, 109, -119, 107, -119,
	-87, -28, -10, 31, -27, -91, 166, 104, 164, 161,
	-95, 31, -95, 164, 88, -76, 162, 163, 9, 17,
	-108, -82, -7, -3, -121, 163, 161, -72, 165, 162,
	-76, 162, -20, -125, 162, 163, 165, -23, -126, 31,
	163, 162, 163, 107, -95, -72, 165, 165, 163, -106,
	-9, -72, 161, -96, 161, -88, -56, 88, 37, 17,
	162, -46, -23, 163, 9, 17, -7, 162, -120, -41,
	-42, -43, -44, -45, -9, -7, 154, 86, 162, 162,
	-26, -10, 31, -126, -72, 163, 161, 102, -28, 88,
	35, 162, -72, -72, 165, 9, 88, -23, -82, -23,
	164, 162, -41, 163, 163, 121, 105, 153, -72, -72,
	-72, 163, 165, -9, 162, 162, -56, -75, -83, 86,
	-5, -100, -7, 100, 162, 161, 165, -7, 163, -72,
	-95, 162, -84, 163, 161, -72, 162,
}
var yyDef = [...]int{

	79, -2, 1, 78, 85, 86, 87, 88, 89, 0,
	0, 0, 0, 122, 130, 131, 0, 0, 0, 0,
	416, 416, 416, 0, 381, 0, 142, 0, 0, 0,
	0, 148, 0, 0, 0, 80, 369, 0, 0, 0,
	0, 204, 0, -2, 415, 169, 0, -2, 432, 418,
	0, 452, 0, 0, 0, 0, 0, 0, 0, 0,
	346, 350, 0, 0, 0, 0, 0, 0, 0, 385,
	0, 360, 387, 0, 363, 0, 171, 172, 425, 410,
	430, 0, 0, -2, 0, 0, 0, 0, 0, 0,
	0, 0, 395, 396, 397, 398, 399, 400, 401, 402,
	403, 404, 0, 0, 434, 0, -2, 0, 0, 394,
	82, 0, 0, 0, 0, 79, 80, 0, 0, 0,
	115, 0, 99, 100, 112, 117, 0, 120, 0, 0,
	0, 0, 369, 0, 286, 0, 0, 417, 381, 0,
	0, 0, 232, 233, 0, 369, 235, 236, 0, 284,
	285, 143, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 122, 0, 0, 152, 0, 370,
	0, 170, 175, 0, 177, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 310, 312, 0, 416, 0, 0, 452,
	0, 451, 455, 453, 457, 0, 0, 297, -2, 0,
	0, -2, 381, 452, -2, 331, 332, 333, 334, 0,
	351, 352, 353, 354, 355, 356, 357, 358, 416, 359,
	0, 388, 389, 464, 466, 0, 0, 362, 364, 366,
	416, 0, 0, 390, 292, 383, 384, 390, 382, 439,
	0, 0, 479, 480, 0, 482, 483, 0, 406, 0,
	0, 0, 0, 436, 377, 0, 380, 452, 0, 84,
	0, 83, 91, 79, 0, 94, 0, 0, 115, 0,
	96, 0, 0, 0, 115, 118, 98, 0, 0, 121,
	129, 123, 124, 125, 126, 127, 0, 0, 0, 0,
	0, 287, 289, 0, 136, 137, 138, 139, 0, 140,
	0, 0, 0, 141, 0, 314, 315, 316, 317, 318,
	319, 320, 321, 322, 323, 324, 325, 326, 327, 328,
	329, 330, -2, -2, -2, -2, -2, -2, -2, -2,
	-2, 344, 0, 0, 349, 105, 159, -2, 0, 0,
	0, 150, 151, 0, -2, 175, 179, 0, 239, 0,
	0, 0, 205, 0, 208, 122, 295, 0, 298, 299,
	300, 301, 302, 303, 304, 305, 306, 307, 308, 309,
	0, 0, 0, 433, 448, 0, 450, 0, 393, 452,
	0, -2, 452, 0, 0, -2, 0, 361, 465, 462,
	463, 0, 0, 0, 0, 419, 0, 0, 0, -2,
	-2, 0, 76, 77, 69, 70, 71, 72, 73, 74,
	75, 2, 3, 4, 5, 6, 7, 8, 9, 10,
	11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
	21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
	31, 32, 33, 34, 35, 36, 37, 38, 39, 40,
	41, 42, 43, 44, 45, 46, 47, 48, 49, 50,
	51, 52, 53, 54, 55, 56, 57, 58, 59, 60,
	61, 62, 63, 64, 65, 66, 67, 68, 0, -2,
	-2, 291, 391, 0, 416, 0, 0, 0, 175, 105,
	484, 486, 0, 0, 405, 408, 407, 0, 225, 105,
	227, 229, 0, 0, 81, 90, 0, 93, 95, 97,
	0, 115, 111, 0, 115, 0, 116, 0, 119, 282,
	0, 0, 0, 286, 0, 0, 231, 234, -2, 237,
	283, 0, 348, 0, 106, 0, 0, 153, -2, 0,
	210, 212, 163, 217, 218, 0, 220, 221, 222, 179,
	0, 0, 176, 265, 239, 178, 244, 0, 0, 0,
	296, 0, 426, 428, 429, 0, 0, 0, 454, 456,
	0, 0, 0, -2, 393, 386, 0, 473, 474, 0,
	476, 468, 469, 470, 0, 472, 365, 427, 378, 0,
	379, 443, 0, 0, 442, 444, 179, 0, 106, 478,
	481, 435, 0, 106, 230, 392, 92, 0, 0, 105,
	108, 113, 0, 0, 0, 132, 200, 122, 0, 0,
	288, 135, 195, 195, 0, 347, 0, 160, 0, -2,
	0, 0, 452, 147, 189, 122, 157, 0, 371, 216,
	165, 164, 219, 0, 239, 180, 173, 238, 0, 0,
	0, -2, 264, 267, 269, 270, 271, 272, 273, 274,
	265, 0, 0, 0, 0, 202, 122, 449, 0, 294,
	-2, 452, 461, 467, 475, 0, 446, 440, 441, 0,
	477, 485, 226, 228, 105, 110, 0, 0, 106, 114,
	105, 128, 0, 0, 286, 0, 195, 0, 195, 371,
	144, 0, 0, -2, 452, 0, 0, 149, 0, 0,
	223, 223, 0, 213, 0, 166, 239, 265, 0, 276,
	277, 0, 369, 0, 268, 174, 245, 203, 122, 209,
	206, 293, 0, 0, 239, 0, 106, 105, 103, 107,
	0, 0, 133, 0, 191, 0, 0, 0, 0, 0,
	223, 145, 187, 122, 0, 0, -2, 0, 0, 122,
	0, 0, 0, 0, 214, 265, 168, 240, 0, 0,
	0, 280, 0, 0, 242, 246, 0, 207, 460, 471,
	265, 101, 109, 0, 104, 201, 0, 0, 122, 198,
	199, 192, 193, 0, 0, 0, 0, 183, 190, 0,
	155, 0, 122, 224, 122, 0, 374, 375, 0, 0,
	167, 275, 278, 241, 0, 0, 0, 247, 0, 249,
	0, 0, 259, 0, 0, 258, 57, -2, 290, 102,
	134, 185, 122, 122, 197, 194, 122, 0, 146, 0,
	0, 158, 0, 0, 372, 0, 376, 215, 279, 281,
	-2, 248, 250, 251, 252, 0, 0, 0, 0, 196,
	0, 188, 0, 156, 162, 367, 373, 0, 253, 254,
	255, 257, 260, 0, 368, 122, 223, 256, 186, 0,
	0, 154, 243, 261, 122, 0, 262,
}
var yyTok1 = [...]int{

	1, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 55, 159, 3, 167, 54, 37, 3,
	164, 165, 52, 49, 9, 50, 51, 53, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 31, 163,
	43, 17, 45, 30, 67, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 69, 3, 166, 36, 3, 160, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 161, 35, 162, 57,
}
var yyTok2 = [...]int{

	2, 3, 4, 5, 6, 7, 8, 10, 11, 12,
	13, 14, 15, 16, 18, 19, 20, 21, 22, 23,
	24, 25, 26, 27, 28, 29, 32, 33, 34, 38,
	39, 40, 41, 42, 44, 46, 47, 48, 56, 58,
	59, 60, 61, 62, 63, 64, 65, 66, 68, 70,
	71, 72, 73, 74, 75, 76, 77, 78, 79, 80,
	81, 82, 83, 84, 85, 86, 87, 88, 89, 90,
	91, 92, 93, 94, 95, 96, 97, 98, 99, 100,
	101, 102, 103, 104, 105, 106, 107, 108, 109, 110,
	111, 112, 113, 114, 115, 116, 117, 118, 119, 120,
	121, 122, 123, 124, 125, 126, 127, 128, 129, 130,
	131, 132, 133, 134, 135, 136, 137, 138, 139, 140,
	141, 142, 143, 144, 145, 146, 147, 148, 149, 150,
	151, 152, 153, 154, 155, 156, 157, 158,
}
var yyTok3 = [...]int{
	0,
}

var yyErrorMessages = [...]struct {
	state int
	token int
	msg   string
}{}

//line yaccpar:1

/*	parser for yacc output	*/

var (
	yyDebug        = 0
	yyErrorVerbose = false
)

type yyLexer interface {
	Lex(lval *yySymType) int
	Error(s string)
}

type yyParser interface {
	Parse(yyLexer) int
	Lookahead() int
}

type yyParserImpl struct {
	lval  yySymType
	stack [yyInitialStackSize]yySymType
	char  int
}

func (p *yyParserImpl) Lookahead() int {
	return p.char
}

func yyNewParser() yyParser {
	return &yyParserImpl{}
}

const yyFlag = -1000

func yyTokname(c int) string {
	if c >= 1 && c-1 < len(yyToknames) {
		if yyToknames[c-1] != "" {
			return yyToknames[c-1]
		}
	}
	return __yyfmt__.Sprintf("tok-%v", c)
}

func yyStatname(s int) string {
	if s >= 0 && s < len(yyStatenames) {
		if yyStatenames[s] != "" {
			return yyStatenames[s]
		}
	}
	return __yyfmt__.Sprintf("state-%v", s)
}

func yyErrorMessage(state, lookAhead int) string {
	const TOKSTART = 4

	if !yyErrorVerbose {
		return "syntax error"
	}

	for _, e := range yyErrorMessages {
		if e.state == state && e.token == lookAhead {
			return "syntax error: " + e.msg
		}
	}

	res := "syntax error: unexpected " + yyTokname(lookAhead)

	// To match Bison, suggest at most four expected tokens.
	expected := make([]int, 0, 4)

	// Look for shiftable tokens.
	base := yyPact[state]
	for tok := TOKSTART; tok-1 < len(yyToknames); tok++ {
		if n := base + tok; n >= 0 && n < yyLast && yyChk[yyAct[n]] == tok {
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}
	}

	if yyDef[state] == -2 {
		i := 0
		for yyExca[i] != -1 || yyExca[i+1] != state {
			i += 2
		}

		// Look for tokens that we accept or reduce.
		for i += 2; yyExca[i] >= 0; i += 2 {
			tok := yyExca[i]
			if tok < TOKSTART || yyExca[i+1] == 0 {
				continue
			}
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}

		// If the default action is to accept or reduce, give up.
		if yyExca[i+1] != 0 {
			return res
		}
	}

	for i, tok := range expected {
		if i == 0 {
			res += ", expecting "
		} else {
			res += " or "
		}
		res += yyTokname(tok)
	}
	return res
}

func yylex1(lex yyLexer, lval *yySymType) (char, token int) {
	token = 0
	char = lex.Lex(lval)
	if char <= 0 {
		token = yyTok1[0]
		goto out
	}
	if char < len(yyTok1) {
		token = yyTok1[char]
		goto out
	}
	if char >= yyPrivate {
		if char < yyPrivate+len(yyTok2) {
			token = yyTok2[char-yyPrivate]
			goto out
		}
	}
	for i := 0; i < len(yyTok3); i += 2 {
		token = yyTok3[i+0]
		if token == char {
			token = yyTok3[i+1]
			goto out
		}
	}

out:
	if token == 0 {
		token = yyTok2[1] /* unknown char */
	}
	if yyDebug >= 3 {
		__yyfmt__.Printf("lex %s(%d)\n", yyTokname(token), uint(char))
	}
	return char, token
}

func yyParse(yylex yyLexer) int {
	return yyNewParser().Parse(yylex)
}

func (yyrcvr *yyParserImpl) Parse(yylex yyLexer) int {
	var yyn int
	var yyVAL yySymType
	var yyDollar []yySymType
	_ = yyDollar // silence set and not used
	yyS := yyrcvr.stack[:]

	Nerrs := 0   /* number of errors */
	Errflag := 0 /* error recovery flag */
	yystate := 0
	yyrcvr.char = -1
	yytoken := -1 // yyrcvr.char translated into internal numbering
	defer func() {
		// Make sure we report no lookahead when not parsing.
		yystate = -1
		yyrcvr.char = -1
		yytoken = -1
	}()
	yyp := -1
	goto yystack

ret0:
	return 0

ret1:
	return 1

yystack:
	/* put a state and value onto the stack */
	if yyDebug >= 4 {
		__yyfmt__.Printf("char %v in %v\n", yyTokname(yytoken), yyStatname(yystate))
	}

	yyp++
	if yyp >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyS[yyp] = yyVAL
	yyS[yyp].yys = yystate

yynewstate:
	yyn = yyPact[yystate]
	if yyn <= yyFlag {
		goto yydefault /* simple state */
	}
	if yyrcvr.char < 0 {
		yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
	}
	yyn += yytoken
	if yyn < 0 || yyn >= yyLast {
		goto yydefault
	}
	yyn = yyAct[yyn]
	if yyChk[yyn] == yytoken { /* valid shift */
		yyrcvr.char = -1
		yytoken = -1
		yyVAL = yyrcvr.lval
		yystate = yyn
		if Errflag > 0 {
			Errflag--
		}
		goto yystack
	}

yydefault:
	/* default state action */
	yyn = yyDef[yystate]
	if yyn == -2 {
		if yyrcvr.char < 0 {
			yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
		}

		/* look through exception table */
		xi := 0
		for {
			if yyExca[xi+0] == -1 && yyExca[xi+1] == yystate {
				break
			}
			xi += 2
		}
		for xi += 2; ; xi += 2 {
			yyn = yyExca[xi+0]
			if yyn < 0 || yyn == yytoken {
				break
			}
		}
		yyn = yyExca[xi+1]
		if yyn < 0 {
			goto ret0
		}
	}
	if yyn == 0 {
		/* error ... attempt to resume parsing */
		switch Errflag {
		case 0: /* brand new error */
			yylex.Error(yyErrorMessage(yystate, yytoken))
			Nerrs++
			if yyDebug >= 1 {
				__yyfmt__.Printf("%s", yyStatname(yystate))
				__yyfmt__.Printf(" saw %s\n", yyTokname(yytoken))
			}
			fallthrough

		case 1, 2: /* incompletely recovered error ... try again */
			Errflag = 3

			/* find a state where "error" is a legal shift action */
			for yyp >= 0 {
				yyn = yyPact[yyS[yyp].yys] + yyErrCode
				if yyn >= 0 && yyn < yyLast {
					yystate = yyAct[yyn] /* simulate a shift of "error" */
					if yyChk[yystate] == yyErrCode {
						goto yystack
					}
				}

				/* the current p has no shift on "error", pop stack */
				if yyDebug >= 2 {
					__yyfmt__.Printf("error recovery pops state %d\n", yyS[yyp].yys)
				}
				yyp--
			}
			/* there is no state on the stack with an error shift ... abort */
			goto ret1

		case 3: /* no shift yet; clobber input char */
			if yyDebug >= 2 {
				__yyfmt__.Printf("error recovery discards %s\n", yyTokname(yytoken))
			}
			if yytoken == yyEofCode {
				goto ret1
			}
			yyrcvr.char = -1
			yytoken = -1
			goto yynewstate /* try again in the same state */
		}
	}

	/* reduction by production yyn */
	if yyDebug >= 2 {
		__yyfmt__.Printf("reduce %v in:\n\t%v\n", yyn, yyStatname(yystate))
	}

	yynt := yyn
	yypt := yyp
	_ = yypt // guard against "declared and not used"

	yyp -= yyR2[yyn]
	// yyp is now the index of $0. Perform the default action. Iff the
	// reduced production is ε, $1 is possibly out of range.
	if yyp+1 >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyVAL = yyS[yyp+1]

	/* consult goto table to find next state */
	yyn = yyR1[yyn]
	yyg := yyPgo[yyn]
	yyj := yyg + yyS[yyp].yys + 1

	if yyj >= yyLast {
		yystate = yyAct[yyg]
	} else {
		yystate = yyAct[yyj]
		if yyChk[yystate] != -yyn {
			yystate = yyAct[yyg]
		}
	}
	// dummy call; replaced with literal code
	switch yynt {

	case 1:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:236
		{
			rootnode = yyDollar[1].node
		}
	case 2:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:240
		{
			yyVAL.token = yyDollar[1].token
		}
	case 3:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:240
		{
			yyVAL.token = yyDollar[1].token
		}
	case 4:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:240
		{
			yyVAL.token = yyDollar[1].token
		}
	case 5:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:240
		{
			yyVAL.token = yyDollar[1].token
		}
	case 6:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:240
		{
			yyVAL.token = yyDollar[1].token
		}
	case 7:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:240
		{
			yyVAL.token = yyDollar[1].token
		}
	case 8:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:240
		{
			yyVAL.token = yyDollar[1].token
		}
	case 9:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:240
		{
			yyVAL.token = yyDollar[1].token
		}
	case 10:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:241
		{
			yyVAL.token = yyDollar[1].token
		}
	case 11:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:241
		{
			yyVAL.token = yyDollar[1].token
		}
	case 12:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:241
		{
			yyVAL.token = yyDollar[1].token
		}
	case 13:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:241
		{
			yyVAL.token = yyDollar[1].token
		}
	case 14:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:241
		{
			yyVAL.token = yyDollar[1].token
		}
	case 15:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:241
		{
			yyVAL.token = yyDollar[1].token
		}
	case 16:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:241
		{
			yyVAL.token = yyDollar[1].token
		}
	case 17:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:241
		{
			yyVAL.token = yyDollar[1].token
		}
	case 18:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:241
		{
			yyVAL.token = yyDollar[1].token
		}
	case 19:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:241
		{
			yyVAL.token = yyDollar[1].token
		}
	case 20:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:241
		{
			yyVAL.token = yyDollar[1].token
		}
	case 21:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:241
		{
			yyVAL.token = yyDollar[1].token
		}
	case 22:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:242
		{
			yyVAL.token = yyDollar[1].token
		}
	case 23:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:242
		{
			yyVAL.token = yyDollar[1].token
		}
	case 24:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:242
		{
			yyVAL.token = yyDollar[1].token
		}
	case 25:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:242
		{
			yyVAL.token = yyDollar[1].token
		}
	case 26:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:242
		{
			yyVAL.token = yyDollar[1].token
		}
	case 27:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:242
		{
			yyVAL.token = yyDollar[1].token
		}
	case 28:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:242
		{
			yyVAL.token = yyDollar[1].token
		}
	case 29:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:242
		{
			yyVAL.token = yyDollar[1].token
		}
	case 30:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:242
		{
			yyVAL.token = yyDollar[1].token
		}
	case 31:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:242
		{
			yyVAL.token = yyDollar[1].token
		}
	case 32:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:243
		{
			yyVAL.token = yyDollar[1].token
		}
	case 33:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:243
		{
			yyVAL.token = yyDollar[1].token
		}
	case 34:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:243
		{
			yyVAL.token = yyDollar[1].token
		}
	case 35:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:243
		{
			yyVAL.token = yyDollar[1].token
		}
	case 36:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:243
		{
			yyVAL.token = yyDollar[1].token
		}
	case 37:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:243
		{
			yyVAL.token = yyDollar[1].token
		}
	case 38:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:243
		{
			yyVAL.token = yyDollar[1].token
		}
	case 39:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:243
		{
			yyVAL.token = yyDollar[1].token
		}
	case 40:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:243
		{
			yyVAL.token = yyDollar[1].token
		}
	case 41:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:243
		{
			yyVAL.token = yyDollar[1].token
		}
	case 42:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:244
		{
			yyVAL.token = yyDollar[1].token
		}
	case 43:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:244
		{
			yyVAL.token = yyDollar[1].token
		}
	case 44:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:244
		{
			yyVAL.token = yyDollar[1].token
		}
	case 45:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:244
		{
			yyVAL.token = yyDollar[1].token
		}
	case 46:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:244
		{
			yyVAL.token = yyDollar[1].token
		}
	case 47:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:244
		{
			yyVAL.token = yyDollar[1].token
		}
	case 48:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:244
		{
			yyVAL.token = yyDollar[1].token
		}
	case 49:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:244
		{
			yyVAL.token = yyDollar[1].token
		}
	case 50:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:244
		{
			yyVAL.token = yyDollar[1].token
		}
	case 51:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:244
		{
			yyVAL.token = yyDollar[1].token
		}
	case 52:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:244
		{
			yyVAL.token = yyDollar[1].token
		}
	case 53:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:245
		{
			yyVAL.token = yyDollar[1].token
		}
	case 54:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:245
		{
			yyVAL.token = yyDollar[1].token
		}
	case 55:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:245
		{
			yyVAL.token = yyDollar[1].token
		}
	case 56:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:245
		{
			yyVAL.token = yyDollar[1].token
		}
	case 57:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:245
		{
			yyVAL.token = yyDollar[1].token
		}
	case 58:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:245
		{
			yyVAL.token = yyDollar[1].token
		}
	case 59:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:245
		{
			yyVAL.token = yyDollar[1].token
		}
	case 60:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:245
		{
			yyVAL.token = yyDollar[1].token
		}
	case 61:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:246
		{
			yyVAL.token = yyDollar[1].token
		}
	case 62:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:246
		{
			yyVAL.token = yyDollar[1].token
		}
	case 63:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:246
		{
			yyVAL.token = yyDollar[1].token
		}
	case 64:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:246
		{
			yyVAL.token = yyDollar[1].token
		}
	case 65:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:246
		{
			yyVAL.token = yyDollar[1].token
		}
	case 66:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:246
		{
			yyVAL.token = yyDollar[1].token
		}
	case 67:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:246
		{
			yyVAL.token = yyDollar[1].token
		}
	case 68:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:246
		{
			yyVAL.token = yyDollar[1].token
		}
	case 69:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:250
		{
			yyVAL.token = yyDollar[1].token
		}
	case 70:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:251
		{
			yyVAL.token = yyDollar[1].token
		}
	case 71:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:251
		{
			yyVAL.token = yyDollar[1].token
		}
	case 72:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:251
		{
			yyVAL.token = yyDollar[1].token
		}
	case 73:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:251
		{
			yyVAL.token = yyDollar[1].token
		}
	case 74:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:251
		{
			yyVAL.token = yyDollar[1].token
		}
	case 75:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:251
		{
			yyVAL.token = yyDollar[1].token
		}
	case 76:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:255
		{
			yyVAL.token = yyDollar[1].token
		}
	case 77:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:256
		{
			yyVAL.token = yyDollar[1].token
		}
	case 78:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:260
		{
			yyVAL.node = yyDollar[1].node.Append(yyDollar[2].node)
		}
	case 79:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:261
		{
			yyVAL.node = node.NewSimpleNode("Statements")
		}
	case 80:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:265
		{
			yyVAL.list = []node.Node{name.NewNamePart(yyDollar[1].token)}
		}
	case 81:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:266
		{
			yyVAL.list = append(yyDollar[1].list, name.NewNamePart(yyDollar[3].token))
		}
	case 82:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:270
		{
			yyVAL.node = name.NewName(yyDollar[1].list)
		}
	case 83:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:271
		{
			yyVAL.node = name.NewRelative(yyDollar[3].list)
		}
	case 84:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:272
		{
			yyVAL.node = name.NewFullyQualified(yyDollar[2].list)
		}
	case 85:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:276
		{
			yyVAL.node = yyDollar[1].node
		}
	case 86:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:277
		{
			yyVAL.node = yyDollar[1].node
		}
	case 87:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:278
		{
			yyVAL.node = yyDollar[1].node
		}
	case 88:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:279
		{
			yyVAL.node = yyDollar[1].node
		}
	case 89:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:280
		{
			yyVAL.node = yyDollar[1].node
		}
	case 90:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:281
		{
			yyVAL.node = stmt.NewHaltCompiler(yyDollar[1].token)
		}
	case 91:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:282
		{
			yyVAL.node = stmt.NewNamespace(yyDollar[1].token, name.NewName(yyDollar[2].list), nil)
		}
	case 92:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser/parser.y:284
		{
			yyVAL.node = stmt.NewNamespace(yyDollar[1].token, name.NewName(yyDollar[2].list), yyDollar[4].node.(node.SimpleNode).Children)
		}
	case 93:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:285
		{
			yyVAL.node = stmt.NewNamespace(yyDollar[1].token, nil, yyDollar[3].node.(node.SimpleNode).Children)
		}
	case 94:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:286
		{
			yyVAL.node = yyDollar[2].node.(stmt.GroupUse).SetToken(yyDollar[1].token)
		}
	case 95:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:287
		{
			yyVAL.node = yyDollar[3].node.(stmt.GroupUse).SetToken(yyDollar[1].token).(stmt.GroupUse).SetUseType(yyDollar[2].node)
		}
	case 96:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:288
		{
			yyVAL.node = stmt.NewUseList(yyDollar[1].token, nil, yyDollar[2].list)
		}
	case 97:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:289
		{
			yyVAL.node = stmt.NewUseList(yyDollar[1].token, yyDollar[2].node, yyDollar[3].list)
		}
	case 98:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:290
		{
			yyVAL.node = stmt.NewStmtConst(yyDollar[1].token, yyDollar[2].list)
		}
	case 99:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:294
		{
			yyVAL.node = node.NewSimpleNode("FuncUseType")
		}
	case 100:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:295
		{
			yyVAL.node = node.NewSimpleNode("ConstUseType")
		}
	case 101:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser/parser.y:300
		{
			fmt.Println("group")
			yyVAL.node = stmt.NewGroupUse(nil, nil, name.NewName(yyDollar[1].list), yyDollar[4].list)
		}
	case 102:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser/parser.y:305
		{
			yyVAL.node = stmt.NewGroupUse(nil, nil, name.NewName(yyDollar[2].list), yyDollar[5].list)
		}
	case 103:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser/parser.y:312
		{
			fmt.Println("mixed")
			yyVAL.node = stmt.NewGroupUse(nil, nil, name.NewName(yyDollar[1].list), yyDollar[4].list)
		}
	case 104:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser/parser.y:317
		{
			yyVAL.node = stmt.NewGroupUse(nil, nil, name.NewName(yyDollar[2].list), yyDollar[5].list)
		}
	case 107:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:329
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 108:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:330
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 109:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:335
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 110:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:336
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 111:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:340
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 112:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:341
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 113:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:345
		{
			yyVAL.node = yyDollar[1].node
		}
	case 114:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:346
		{
			yyVAL.node = yyDollar[2].node.(stmt.Use).SetType(yyDollar[1].node)
		}
	case 115:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:350
		{
			yyVAL.node = stmt.NewUse(nil, name.NewName(yyDollar[1].list), nil)
		}
	case 116:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:351
		{
			yyVAL.node = stmt.NewUse(nil, name.NewName(yyDollar[1].list), yyDollar[3].token)
		}
	case 117:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:355
		{
			yyVAL.node = yyDollar[1].node
		}
	case 118:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:356
		{
			yyVAL.node = yyDollar[2].node
		}
	case 119:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:360
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 120:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:361
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 121:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:365
		{
			yyVAL.node = yyDollar[1].node.Append(yyDollar[2].node)
		}
	case 122:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:366
		{
			yyVAL.node = node.NewSimpleNode("StmtList")
		}
	case 123:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:370
		{
			yyVAL.node = yyDollar[1].node
		}
	case 124:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:371
		{
			yyVAL.node = yyDollar[1].node
		}
	case 125:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:372
		{
			yyVAL.node = yyDollar[1].node
		}
	case 126:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:373
		{
			yyVAL.node = yyDollar[1].node
		}
	case 127:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:374
		{
			yyVAL.node = yyDollar[1].node
		}
	case 128:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:375
		{
			yyVAL.node = stmt.NewHaltCompiler(yyDollar[1].token)
		}
	case 129:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:378
		{
			yyVAL.node = stmt.NewStmtList(yyDollar[1].token, yyDollar[3].token, yyDollar[2].node.(node.SimpleNode).Children)
		}
	case 130:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:379
		{
			yyVAL.node = yyDollar[1].node
		}
	case 131:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:380
		{
			yyVAL.node = yyDollar[1].node
		}
	case 132:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser/parser.y:382
		{
			yyVAL.node = stmt.NewWhile(yyDollar[1].token, yyDollar[3].node, yyDollar[5].node)
		}
	case 133:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser/parser.y:383
		{
			yyVAL.node = stmt.NewDo(yyDollar[1].token, yyDollar[2].node, yyDollar[5].node)
		}
	case 134:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser/parser.y:385
		{
			yyVAL.node = stmt.NewFor(yyDollar[1].token, yyDollar[3].list, yyDollar[5].list, yyDollar[7].list, yyDollar[9].node)
		}
	case 135:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser/parser.y:386
		{
			yyVAL.node = stmt.NewSwitch(yyDollar[1].token, yyDollar[3].node, yyDollar[5].list)
		}
	case 136:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:387
		{
			yyVAL.node = stmt.NewBreak(yyDollar[1].token, yyDollar[2].node)
		}
	case 137:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:388
		{
			yyVAL.node = stmt.NewContinue(yyDollar[1].token, yyDollar[2].node)
		}
	case 138:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:389
		{
			yyVAL.node = stmt.NewReturn(yyDollar[1].token, yyDollar[2].node)
		}
	case 139:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:390
		{
			yyVAL.node = stmt.NewGlobal(yyDollar[1].token, yyDollar[2].list)
		}
	case 140:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:391
		{
			yyVAL.node = stmt.NewStatic(yyDollar[1].token, yyDollar[2].list)
		}
	case 141:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:392
		{
			yyVAL.node = stmt.NewEcho(yyDollar[1].token, yyDollar[2].list)
		}
	case 142:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:393
		{
			yyVAL.node = stmt.NewInlineHtml(yyDollar[1].token)
		}
	case 143:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:394
		{
			yyVAL.node = stmt.NewExpression(yyDollar[1].node)
		}
	case 144:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser/parser.y:396
		{
			yyVAL.node = stmt.NewUnset(yyDollar[1].token, yyDollar[3].list)
		}
	case 145:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser/parser.y:398
		{
			yyVAL.node = stmt.NewForeach(yyDollar[1].token, yyDollar[3].node, nil, yyDollar[5].node, yyDollar[7].node)
		}
	case 146:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser/parser.y:400
		{
			yyVAL.node = stmt.NewForeach(yyDollar[1].token, yyDollar[3].node, yyDollar[5].node, yyDollar[7].node, yyDollar[9].node)
		}
	case 147:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser/parser.y:401
		{
			yyVAL.node = stmt.NewDeclare(yyDollar[1].token, yyDollar[3].list, yyDollar[5].node)
		}
	case 148:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:402
		{
			yyVAL.node = stmt.NewNop(yyDollar[1].token)
		}
	case 149:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser/parser.y:404
		{
			yyVAL.node = stmt.NewTry(yyDollar[1].token, yyDollar[3].node.(node.SimpleNode).Children, yyDollar[5].list, yyDollar[6].node)
		}
	case 150:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:407
		{
			yyVAL.node = stmt.NewThrow(yyDollar[1].token, yyDollar[2].node)
		}
	case 151:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:408
		{
			yyVAL.node = stmt.NewGoto(yyDollar[1].token, yyDollar[2].token)
		}
	case 152:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:409
		{
			yyVAL.node = stmt.NewLabel(yyDollar[1].token)
		}
	case 153:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:412
		{
			yyVAL.list = []node.Node{}
		}
	case 154:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser/parser.y:414
		{
			yyVAL.list = append(yyDollar[1].list, stmt.NewCatch(yyDollar[2].token, yyDollar[4].list, expr.NewVariable(yyDollar[5].token), yyDollar[8].node.(node.SimpleNode).Children))
		}
	case 155:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:417
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 156:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:418
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 157:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:422
		{
			yyVAL.node = nil
		}
	case 158:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:423
		{
			yyVAL.node = stmt.NewFinally(yyDollar[1].token, yyDollar[3].node.(node.SimpleNode).Children)
		}
	case 159:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:427
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 160:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:428
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 161:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:432
		{
			yyVAL.node = yyDollar[1].node
		}
	case 162:
		yyDollar = yyS[yypt-10 : yypt+1]
		//line parser/parser.y:437
		{
			yyVAL.node = stmt.NewFunction(yyDollar[3].token, yyDollar[2].value == "true", yyDollar[5].node.(node.SimpleNode).Children, yyDollar[7].node, yyDollar[9].node.(node.SimpleNode).Children)
		}
	case 163:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:443
		{
			yyVAL.value = "false"
		}
	case 164:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:444
		{
			yyVAL.value = "true"
		}
	case 165:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:448
		{
			yyVAL.value = "false"
		}
	case 166:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:449
		{
			yyVAL.value = "true"
		}
	case 167:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line parser/parser.y:454
		{
			yyVAL.node = stmt.NewClass(yyDollar[3].token, yyDollar[1].strings, nil, yyDollar[4].node, yyDollar[5].node.(node.SimpleNode).Children, yyDollar[7].node.(node.SimpleNode).Children)
		}
	case 168:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser/parser.y:456
		{
			yyVAL.node = stmt.NewClass(yyDollar[2].token, nil, nil, yyDollar[3].node, yyDollar[4].node.(node.SimpleNode).Children, yyDollar[6].node.(node.SimpleNode).Children)
		}
	case 169:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:460
		{
			yyVAL.strings = []string{yyDollar[1].value}
		}
	case 170:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:461
		{
			yyVAL.strings = append(yyDollar[1].strings, yyDollar[2].value)
		}
	case 171:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:465
		{
			yyVAL.value = "abstract"
		}
	case 172:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:466
		{
			yyVAL.value = "final"
		}
	case 173:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser/parser.y:470
		{
			yyVAL.node = stmt.NewTrait(yyDollar[2].token, yyDollar[4].node.(node.SimpleNode).Children)
		}
	case 174:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser/parser.y:475
		{
			yyVAL.node = stmt.NewInterface(yyDollar[1].token, yyDollar[2].token, yyDollar[3].node, yyDollar[5].node.(node.SimpleNode).Children)
		}
	case 175:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:479
		{
			yyVAL.node = nil
		}
	case 176:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:480
		{
			yyVAL.node = yyDollar[2].node
		}
	case 177:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:484
		{
			yyVAL.node = nil
		}
	case 178:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:485
		{
			yyVAL.node = yyDollar[2].node
		}
	case 179:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:489
		{
			yyVAL.node = node.NewSimpleNode("TODO: must be nil")
		}
	case 180:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:490
		{
			yyVAL.node = yyDollar[2].node
		}
	case 181:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:494
		{
			yyVAL.node = yyDollar[1].node
		}
	case 182:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:495
		{
			yyVAL.node = node.NewSimpleNode("Ref").Append(yyDollar[2].node)
		}
	case 183:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:496
		{
			yyVAL.node = node.NewSimpleNode("List").Append(yyDollar[3].node)
		}
	case 184:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:497
		{
			yyVAL.node = node.NewSimpleNode("ShortList").Append(yyDollar[2].node)
		}
	case 185:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:501
		{
			yyVAL.node = yyDollar[1].node
		}
	case 186:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:502
		{
			yyVAL.node = yyDollar[2].node
		}
	case 187:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:506
		{
			yyVAL.node = yyDollar[1].node
		}
	case 188:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:507
		{
			yyVAL.node = yyDollar[2].node
		}
	case 189:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:511
		{
			yyVAL.node = yyDollar[1].node
		}
	case 190:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:512
		{
			yyVAL.node = yyDollar[2].node
		}
	case 191:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:516
		{
			yyVAL.list = yyDollar[2].list
		}
	case 192:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:517
		{
			yyVAL.list = yyDollar[3].list
		}
	case 193:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:518
		{
			yyVAL.list = yyDollar[2].list
		}
	case 194:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser/parser.y:519
		{
			yyVAL.list = yyDollar[3].list
		}
	case 195:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:523
		{
			yyVAL.list = []node.Node{}
		}
	case 196:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser/parser.y:525
		{
			yyVAL.list = append(yyDollar[1].list, stmt.NewCase(yyDollar[2].token, yyDollar[3].node, yyDollar[5].node.(node.SimpleNode).Children))
		}
	case 197:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:529
		{
			yyVAL.list = append(yyDollar[1].list, stmt.NewDefault(yyDollar[2].token, yyDollar[4].node.(node.SimpleNode).Children))
		}
	case 200:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:540
		{
			yyVAL.node = yyDollar[1].node
		}
	case 201:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:541
		{
			yyVAL.node = yyDollar[2].node
		}
	case 202:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser/parser.y:545
		{
			yyVAL.node = stmt.NewIf(yyDollar[1].token, yyDollar[3].node, yyDollar[5].node)
		}
	case 203:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser/parser.y:547
		{
			_elseIf := stmt.NewElseIf(yyDollar[2].token, yyDollar[4].node, yyDollar[6].node)
			yyVAL.node = yyDollar[1].node.(stmt.If).AddElseIf(_elseIf)
		}
	case 204:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:554
		{
			yyVAL.node = yyDollar[1].node
		}
	case 205:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:556
		{
			_else := stmt.NewElse(yyDollar[2].token, yyDollar[3].node)
			yyVAL.node = yyDollar[1].node.(stmt.If).SetElse(_else)
		}
	case 206:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser/parser.y:564
		{
			yyVAL.node = node.NewSimpleNode("AltIf").
				Append(node.NewSimpleNode("expr").Append(yyDollar[3].node)).
				Append(node.NewSimpleNode("stmt").Append(yyDollar[6].node))
		}
	case 207:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser/parser.y:570
		{
			yyVAL.node = yyDollar[1].node.Append(node.NewSimpleNode("AltElseIf").
				Append(node.NewSimpleNode("expr").Append(yyDollar[4].node)).
				Append(node.NewSimpleNode("stmt").Append(yyDollar[7].node)))
		}
	case 208:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:578
		{
			yyVAL.node = yyDollar[1].node
		}
	case 209:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser/parser.y:580
		{
			yyVAL.node = yyDollar[1].node.Append(node.NewSimpleNode("AltElse").Append(node.NewSimpleNode("stmt").Append(yyDollar[4].node)))
		}
	case 210:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:586
		{
			yyVAL.node = yyDollar[1].node
		}
	case 211:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:587
		{
			yyVAL.node = node.NewSimpleNode("Parameter list")
		}
	case 212:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:591
		{
			yyVAL.node = node.NewSimpleNode("Parameter list").Append(yyDollar[1].node)
		}
	case 213:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:592
		{
			yyVAL.node = yyDollar[1].node.Append(yyDollar[3].node)
		}
	case 214:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:597
		{
			yyVAL.node = node.NewSimpleNode("Parameter").
				Append(yyDollar[1].node).
				Attribute("is_reference", yyDollar[2].value).
				Attribute("is_variadic", yyDollar[3].value).
				Attribute("var", yyDollar[4].token.String())
		}
	case 215:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser/parser.y:605
		{
			yyVAL.node = node.NewSimpleNode("Parameter").
				Append(yyDollar[1].node).
				Attribute("is_reference", yyDollar[2].value).
				Attribute("is_variadic", yyDollar[3].value).
				Attribute("var", yyDollar[4].token.String()).
				Append(yyDollar[6].node)
		}
	case 216:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:616
		{
			yyVAL.node = node.NewSimpleNode("No type")
		}
	case 217:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:617
		{
			yyVAL.node = yyDollar[1].node
		}
	case 218:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:621
		{
			yyVAL.node = yyDollar[1].node
		}
	case 219:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:622
		{
			yyVAL.node = yyDollar[2].node
			yyVAL.node.Attribute("nullable", "true")
		}
	case 220:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:626
		{
			yyVAL.node = node.NewSimpleNode("array type")
		}
	case 221:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:627
		{
			yyVAL.node = node.NewSimpleNode("callable type")
		}
	case 222:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:628
		{
			yyVAL.node = yyDollar[1].node
		}
	case 223:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:632
		{
			yyVAL.node = node.NewSimpleNode("No return type")
		}
	case 224:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:633
		{
			yyVAL.node = yyDollar[2].node
		}
	case 225:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:637
		{
			yyVAL.node = node.NewSimpleNode("ArgumentList")
		}
	case 226:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:638
		{
			yyVAL.node = yyDollar[2].node
		}
	case 227:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:642
		{
			yyVAL.node = node.NewSimpleNode("ArgumentList").Append(yyDollar[1].node)
		}
	case 228:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:643
		{
			yyVAL.node = yyDollar[1].node.Append(yyDollar[3].node)
		}
	case 229:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:647
		{
			yyVAL.node = yyDollar[1].node
		}
	case 230:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:648
		{
			yyVAL.node = node.NewSimpleNode("Unpack").Append(yyDollar[2].node)
		}
	case 231:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:652
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 232:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:653
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 233:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:657
		{
			yyVAL.node = yyDollar[1].node
		}
	case 234:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:661
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 235:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:662
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 236:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:666
		{
			yyVAL.node = stmt.NewStaticVar(yyDollar[1].token, nil)
		}
	case 237:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:667
		{
			yyVAL.node = stmt.NewStaticVar(yyDollar[1].token, yyDollar[3].node)
		}
	case 238:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:671
		{
			yyVAL.node = yyDollar[1].node.Append(yyDollar[2].node)
		}
	case 239:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:672
		{
			yyVAL.node = node.NewSimpleNode("Stmt")
		}
	case 240:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:676
		{
			yyVAL.node = stmt.NewPropertyList(yyDollar[1].node, yyDollar[2].list)
		}
	case 241:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:677
		{
			yyVAL.node = stmt.NewClassConst(yyDollar[2].token, yyDollar[1].node.(node.SimpleNode).Children, yyDollar[3].list)
		}
	case 242:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:678
		{
			yyVAL.node = stmt.NewTraitUse(yyDollar[1].token, yyDollar[2].node.(node.SimpleNode).Children, yyDollar[3].list)
		}
	case 243:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line parser/parser.y:680
		{
			yyVAL.node = stmt.NewClassMethod(yyDollar[4].token, yyDollar[1].node.(node.SimpleNode).Children, yyDollar[3].value == "true", yyDollar[6].node.(node.SimpleNode).Children, yyDollar[8].node, yyDollar[9].node.(node.SimpleNode).Children)
		}
	case 244:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:686
		{
			yyVAL.node = node.NewSimpleNode("NameList").Append(yyDollar[1].node)
		}
	case 245:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:687
		{
			yyVAL.node = yyDollar[1].node.Append(yyDollar[3].node)
		}
	case 246:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:691
		{
			yyVAL.list = nil
		}
	case 247:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:692
		{
			yyVAL.list = nil
		}
	case 248:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:693
		{
			yyVAL.list = yyDollar[2].list
		}
	case 249:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:697
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 250:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:698
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)
		}
	case 251:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:702
		{
			yyVAL.node = yyDollar[1].node
		}
	case 252:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:703
		{
			yyVAL.node = yyDollar[1].node
		}
	case 253:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:708
		{
			name := name.NewName(yyDollar[3].node.(node.SimpleNode).Children)
			yyVAL.node = stmt.NewTraitUsePrecedence(yyDollar[1].node, name)
		}
	case 254:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:715
		{
			yyVAL.node = stmt.NewTraitUseAlias(yyDollar[1].node, nil, yyDollar[3].token)
		}
	case 255:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:717
		{
			yyVAL.node = stmt.NewTraitUseAlias(yyDollar[1].node, nil, yyDollar[3].token)
		}
	case 256:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:719
		{
			yyVAL.node = stmt.NewTraitUseAlias(yyDollar[1].node, yyDollar[3].node, yyDollar[4].token)
		}
	case 257:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:720
		{
			yyVAL.node = stmt.NewTraitUseAlias(yyDollar[1].node, yyDollar[3].node, nil)
		}
	case 258:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:724
		{
			yyVAL.node = stmt.NewTraitMethodRef(nil, yyDollar[1].token)
		}
	case 259:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:725
		{
			yyVAL.node = yyDollar[1].node
		}
	case 260:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:729
		{
			yyVAL.node = stmt.NewTraitMethodRef(yyDollar[1].node, yyDollar[3].token)
		}
	case 261:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:733
		{
			yyVAL.node = node.NewSimpleNode("")
		}
	case 262:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:734
		{
			yyVAL.node = yyDollar[2].node
		}
	case 263:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:738
		{
			yyVAL.node = yyDollar[1].node
		}
	case 264:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:739
		{
			yyVAL.node = node.NewSimpleNode("VarMemberModifier")
		}
	case 265:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:743
		{
			yyVAL.node = node.NewSimpleNode("MemberModifiers").Append(node.NewSimpleNode("PublicMemberModifier"))
		}
	case 266:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:744
		{
			yyVAL.node = yyDollar[1].node
		}
	case 267:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:748
		{
			yyVAL.node = node.NewSimpleNode("MemberModifiers").Append(yyDollar[1].node)
		}
	case 268:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:749
		{
			yyVAL.node = yyDollar[1].node.Append(yyDollar[2].node)
		}
	case 269:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:753
		{
			yyVAL.node = node.NewSimpleNode("PublicMemberModifier")
		}
	case 270:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:754
		{
			yyVAL.node = node.NewSimpleNode("ProtectedMemberModifier")
		}
	case 271:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:755
		{
			yyVAL.node = node.NewSimpleNode("PrivateMemberModifier")
		}
	case 272:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:756
		{
			yyVAL.node = node.NewSimpleNode("StaticMemberModifier")
		}
	case 273:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:757
		{
			yyVAL.node = node.NewSimpleNode("AbstractMemberModifier")
		}
	case 274:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:758
		{
			yyVAL.node = node.NewSimpleNode("FinalMemberModifier")
		}
	case 275:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:762
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 276:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:763
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 277:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:767
		{
			yyVAL.node = stmt.NewProperty(yyDollar[1].token, nil)
		}
	case 278:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:768
		{
			yyVAL.node = stmt.NewProperty(yyDollar[1].token, yyDollar[3].node)
		}
	case 279:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:772
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 280:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:773
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 281:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:777
		{
			yyVAL.node = stmt.NewConstant(yyDollar[1].token, yyDollar[3].node)
		}
	case 282:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:781
		{
			yyVAL.node = stmt.NewConstant(yyDollar[1].token, yyDollar[3].node)
		}
	case 283:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:785
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 284:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:786
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 285:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:790
		{
			yyVAL.node = yyDollar[1].node
		}
	case 286:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:794
		{
			yyVAL.list = nil
		}
	case 287:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:795
		{
			yyVAL.list = yyDollar[1].list
		}
	case 288:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:798
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 289:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:799
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 290:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line parser/parser.y:804
		{
			{
				yyVAL.node = stmt.NewClass(yyDollar[1].token, nil, yyDollar[2].node.(node.SimpleNode).Children, yyDollar[3].node, yyDollar[4].node.(node.SimpleNode).Children, yyDollar[6].node.(node.SimpleNode).Children)
			}
		}
	case 291:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:810
		{
			yyVAL.node = node.NewSimpleNode("New").Append(yyDollar[2].node).Append(yyDollar[3].node)
		}
	case 292:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:811
		{
			yyVAL.node = node.NewSimpleNode("New").Append(yyDollar[2].node)
		}
	case 293:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser/parser.y:815
		{
			yyVAL.node = node.NewSimpleNode("Assign").Append(yyDollar[3].node).Append(yyDollar[6].node)
		}
	case 294:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser/parser.y:816
		{
			yyVAL.node = node.NewSimpleNode("Assign").Append(yyDollar[2].node).Append(yyDollar[5].node)
		}
	case 295:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:817
		{
			yyVAL.node = assign_op.NewAssign(yyDollar[1].node, yyDollar[3].node, false)
		}
	case 296:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:818
		{
			yyVAL.node = assign_op.NewAssign(yyDollar[1].node, yyDollar[4].node, true)
		}
	case 297:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:819
		{
			yyVAL.node = expr.NewClone(yyDollar[2].node)
		}
	case 298:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:820
		{
			yyVAL.node = assign_op.NewPlus(yyDollar[1].node, yyDollar[3].node)
		}
	case 299:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:821
		{
			yyVAL.node = assign_op.NewMinus(yyDollar[1].node, yyDollar[3].node)
		}
	case 300:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:822
		{
			yyVAL.node = assign_op.NewMul(yyDollar[1].node, yyDollar[3].node)
		}
	case 301:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:823
		{
			yyVAL.node = assign_op.NewPow(yyDollar[1].node, yyDollar[3].node)
		}
	case 302:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:824
		{
			yyVAL.node = assign_op.NewDiv(yyDollar[1].node, yyDollar[3].node)
		}
	case 303:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:825
		{
			yyVAL.node = assign_op.NewConcat(yyDollar[1].node, yyDollar[3].node)
		}
	case 304:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:826
		{
			yyVAL.node = assign_op.NewMod(yyDollar[1].node, yyDollar[3].node)
		}
	case 305:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:827
		{
			yyVAL.node = assign_op.NewBitwiseAnd(yyDollar[1].node, yyDollar[3].node)
		}
	case 306:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:828
		{
			yyVAL.node = assign_op.NewBitwiseOr(yyDollar[1].node, yyDollar[3].node)
		}
	case 307:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:829
		{
			yyVAL.node = assign_op.NewBitwiseXor(yyDollar[1].node, yyDollar[3].node)
		}
	case 308:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:830
		{
			yyVAL.node = assign_op.NewShiftLeft(yyDollar[1].node, yyDollar[3].node)
		}
	case 309:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:831
		{
			yyVAL.node = assign_op.NewShiftRight(yyDollar[1].node, yyDollar[3].node)
		}
	case 310:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:832
		{
			yyVAL.node = node.NewSimpleNode("PostIncrement").Append(yyDollar[1].node)
		}
	case 311:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:833
		{
			yyVAL.node = node.NewSimpleNode("PreIncrement").Append(yyDollar[2].node)
		}
	case 312:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:834
		{
			yyVAL.node = node.NewSimpleNode("PostDecrement").Append(yyDollar[1].node)
		}
	case 313:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:835
		{
			yyVAL.node = node.NewSimpleNode("PreDecrement").Append(yyDollar[2].node)
		}
	case 314:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:836
		{
			yyVAL.node = binary_op.NewBooleanOr(yyDollar[1].node, yyDollar[3].node)
		}
	case 315:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:837
		{
			yyVAL.node = binary_op.NewBooleanAnd(yyDollar[1].node, yyDollar[3].node)
		}
	case 316:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:838
		{
			yyVAL.node = binary_op.NewLogicalOr(yyDollar[1].node, yyDollar[3].node)
		}
	case 317:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:839
		{
			yyVAL.node = binary_op.NewLogicalAnd(yyDollar[1].node, yyDollar[3].node)
		}
	case 318:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:840
		{
			yyVAL.node = binary_op.NewLogicalXor(yyDollar[1].node, yyDollar[3].node)
		}
	case 319:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:841
		{
			yyVAL.node = binary_op.NewBitwiseOr(yyDollar[1].node, yyDollar[3].node)
		}
	case 320:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:842
		{
			yyVAL.node = binary_op.NewBitwiseAnd(yyDollar[1].node, yyDollar[3].node)
		}
	case 321:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:843
		{
			yyVAL.node = binary_op.NewBitwiseXor(yyDollar[1].node, yyDollar[3].node)
		}
	case 322:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:844
		{
			yyVAL.node = binary_op.NewConcat(yyDollar[1].node, yyDollar[3].node)
		}
	case 323:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:845
		{
			yyVAL.node = binary_op.NewPlus(yyDollar[1].node, yyDollar[3].node)
		}
	case 324:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:846
		{
			yyVAL.node = binary_op.NewMinus(yyDollar[1].node, yyDollar[3].node)
		}
	case 325:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:847
		{
			yyVAL.node = binary_op.NewMul(yyDollar[1].node, yyDollar[3].node)
		}
	case 326:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:848
		{
			yyVAL.node = binary_op.NewPow(yyDollar[1].node, yyDollar[3].node)
		}
	case 327:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:849
		{
			yyVAL.node = binary_op.NewDiv(yyDollar[1].node, yyDollar[3].node)
		}
	case 328:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:850
		{
			yyVAL.node = binary_op.NewMod(yyDollar[1].node, yyDollar[3].node)
		}
	case 329:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:851
		{
			yyVAL.node = binary_op.NewShiftLeft(yyDollar[1].node, yyDollar[3].node)
		}
	case 330:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:852
		{
			yyVAL.node = binary_op.NewShiftRight(yyDollar[1].node, yyDollar[3].node)
		}
	case 331:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:853
		{
			yyVAL.node = expr.NewUnaryPlus(yyDollar[2].node)
		}
	case 332:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:854
		{
			yyVAL.node = expr.NewUnaryMinus(yyDollar[2].node)
		}
	case 333:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:855
		{
			yyVAL.node = expr.NewBooleanNot(yyDollar[2].node)
		}
	case 334:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:856
		{
			yyVAL.node = expr.NewBitwiseNot(yyDollar[2].node)
		}
	case 335:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:857
		{
			yyVAL.node = binary_op.NewIdentical(yyDollar[1].node, yyDollar[3].node)
		}
	case 336:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:858
		{
			yyVAL.node = binary_op.NewNotIdentical(yyDollar[1].node, yyDollar[3].node)
		}
	case 337:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:859
		{
			yyVAL.node = binary_op.NewEqual(yyDollar[1].node, yyDollar[3].node)
		}
	case 338:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:860
		{
			yyVAL.node = binary_op.NewNotEqual(yyDollar[1].node, yyDollar[3].node)
		}
	case 339:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:861
		{
			yyVAL.node = binary_op.NewSmaller(yyDollar[1].node, yyDollar[3].node)
		}
	case 340:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:862
		{
			yyVAL.node = binary_op.NewSmallerOrEqual(yyDollar[1].node, yyDollar[3].node)
		}
	case 341:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:863
		{
			yyVAL.node = binary_op.NewGreater(yyDollar[1].node, yyDollar[3].node)
		}
	case 342:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:864
		{
			yyVAL.node = binary_op.NewGreaterOrEqual(yyDollar[1].node, yyDollar[3].node)
		}
	case 343:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:865
		{
			yyVAL.node = binary_op.NewSpaceship(yyDollar[1].node, yyDollar[3].node)
		}
	case 344:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:866
		{
			yyVAL.node = node.NewSimpleNode("InstanceOf").Append(yyDollar[1].node).Append(yyDollar[3].node)
		}
	case 345:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:867
		{
			yyVAL.node = yyDollar[2].node
		}
	case 346:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:868
		{
			yyVAL.node = yyDollar[1].node
		}
	case 347:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser/parser.y:869
		{
			yyVAL.node = node.NewSimpleNode("Ternary").Append(yyDollar[1].node).Append(yyDollar[3].node).Append(yyDollar[5].node)
		}
	case 348:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:870
		{
			yyVAL.node = node.NewSimpleNode("Ternary").Append(yyDollar[1].node).Append(yyDollar[4].node)
		}
	case 349:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:871
		{
			yyVAL.node = binary_op.NewCoalesce(yyDollar[1].node, yyDollar[3].node)
		}
	case 350:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:872
		{
			yyVAL.node = yyDollar[1].node
		}
	case 351:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:873
		{
			yyVAL.node = cast.NewCastInt(yyDollar[2].node)
		}
	case 352:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:874
		{
			yyVAL.node = cast.NewCastDouble(yyDollar[2].node)
		}
	case 353:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:875
		{
			yyVAL.node = cast.NewCastString(yyDollar[2].node)
		}
	case 354:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:876
		{
			yyVAL.node = cast.NewCastArray(yyDollar[2].node)
		}
	case 355:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:877
		{
			yyVAL.node = cast.NewCastObject(yyDollar[2].node)
		}
	case 356:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:878
		{
			yyVAL.node = cast.NewCastBool(yyDollar[2].node)
		}
	case 357:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:879
		{
			yyVAL.node = cast.NewCastUnset(yyDollar[2].node)
		}
	case 358:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:880
		{
			yyVAL.node = node.NewSimpleNode("Exit").Append(yyDollar[2].node)
		}
	case 359:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:881
		{
			yyVAL.node = node.NewSimpleNode("Silence").Append(yyDollar[2].node)
		}
	case 360:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:882
		{
			yyVAL.node = yyDollar[1].node
		}
	case 361:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:883
		{
			yyVAL.node = node.NewNodeExprShellExec(yyDollar[1].token, yyDollar[2].list, yyDollar[3].token)
		}
	case 362:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:884
		{
			yyVAL.node = node.NewSimpleNode("Print").Append(yyDollar[2].node)
		}
	case 363:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:885
		{
			yyVAL.node = node.NewSimpleNode("Yield")
		}
	case 364:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:886
		{
			yyVAL.node = node.NewSimpleNode("Yield").Append(yyDollar[2].node)
		}
	case 365:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:887
		{
			yyVAL.node = node.NewSimpleNode("Yield").Append(yyDollar[2].node).Append(yyDollar[4].node)
		}
	case 366:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:888
		{
			yyVAL.node = node.NewSimpleNode("YieldFrom").Append(yyDollar[2].node)
		}
	case 367:
		yyDollar = yyS[yypt-10 : yypt+1]
		//line parser/parser.y:890
		{
			yyVAL.node = node.NewSimpleNode("Closure").
				Attribute("returns_ref", yyDollar[2].value).
				Append(yyDollar[4].node).
				Append(yyDollar[6].node).
				Append(yyDollar[7].node).
				Append(yyDollar[9].node)
		}
	case 368:
		yyDollar = yyS[yypt-11 : yypt+1]
		//line parser/parser.y:899
		{
			yyVAL.node = node.NewSimpleNode("StaticClosure").
				Attribute("returns_ref", yyDollar[3].value).
				Append(yyDollar[5].node).
				Append(yyDollar[7].node).
				Append(yyDollar[8].node).
				Append(yyDollar[10].node)
		}
	case 369:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:910
		{
			yyVAL.value = "false"
		}
	case 370:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:911
		{
			yyVAL.value = "true"
		}
	case 371:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:915
		{
			yyVAL.node = node.NewSimpleNode("")
		}
	case 372:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:916
		{
			yyVAL.node = yyDollar[3].node
		}
	case 373:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:920
		{
			yyVAL.node = yyDollar[1].node.Append(yyDollar[3].node)
		}
	case 374:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:921
		{
			yyVAL.node = node.NewSimpleNode("ClosureUses").Append(yyDollar[1].node)
		}
	case 375:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:925
		{
			yyVAL.node = node.NewSimpleNode("Variable").Attribute("value", yyDollar[1].token.String())
		}
	case 376:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:926
		{
			yyVAL.node = node.NewSimpleNode("Variable").Attribute("value", yyDollar[2].token.String()).Attribute("ref", "true")
		}
	case 377:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:930
		{
			yyVAL.node = node.NewSimpleNode("FunctionCall").Append(yyDollar[1].node).Append(yyDollar[2].node)
		}
	case 378:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:932
		{
			yyVAL.node = node.NewSimpleNode("StaticCall").Append(yyDollar[1].node).Append(yyDollar[3].node).Append(yyDollar[4].node)
		}
	case 379:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:934
		{
			yyVAL.node = node.NewSimpleNode("StaticCall").Append(yyDollar[1].node).Append(yyDollar[3].node).Append(yyDollar[4].node)
		}
	case 380:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:935
		{
			yyVAL.node = node.NewSimpleNode("Call").Append(yyDollar[1].node).Append(yyDollar[2].node)
		}
	case 381:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:939
		{
			yyVAL.node = node.NewSimpleNode("Static")
		}
	case 382:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:940
		{
			yyVAL.node = yyDollar[1].node
		}
	case 383:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:944
		{
			yyVAL.node = yyDollar[1].node
		}
	case 384:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:945
		{
			yyVAL.node = yyDollar[1].node
		}
	case 385:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:949
		{
			yyVAL.node = node.NewSimpleNode("")
		}
	case 386:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:950
		{
			yyVAL.node = yyDollar[2].node
		}
	case 387:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:954
		{
			yyVAL.list = []node.Node{}
		}
	case 388:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:955
		{
			yyVAL.list = []node.Node{scalar.NewEncapsedStringPart(yyDollar[1].token)}
		}
	case 389:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:956
		{
			yyVAL.list = yyDollar[1].list
		}
	case 390:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:960
		{
			yyVAL.node = node.NewSimpleNode("ArgumentList")
		}
	case 391:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:961
		{
			yyVAL.node = yyDollar[1].node
		}
	case 392:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:965
		{
			yyVAL.node = expr.NewArray(yyDollar[1].token, yyDollar[4].token, yyDollar[3].node.(node.SimpleNode).Children, false)
		}
	case 393:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:966
		{
			yyVAL.node = expr.NewArray(yyDollar[1].token, yyDollar[3].token, yyDollar[2].node.(node.SimpleNode).Children, true)
		}
	case 394:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:967
		{
			yyVAL.node = scalar.NewString(yyDollar[1].token)
		}
	case 395:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:971
		{
			yyVAL.node = scalar.NewLnumber(yyDollar[1].token)
		}
	case 396:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:972
		{
			yyVAL.node = scalar.NewDnumber(yyDollar[1].token)
		}
	case 397:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:973
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token)
		}
	case 398:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:974
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token)
		}
	case 399:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:975
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token)
		}
	case 400:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:976
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token)
		}
	case 401:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:977
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token)
		}
	case 402:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:978
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token)
		}
	case 403:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:979
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token)
		}
	case 404:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:980
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token)
		}
	case 405:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:982
		{
			yyVAL.node = scalar.NewString(yyDollar[2].token) /* TODO: mark as Heredoc*/
		}
	case 406:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:984
		{
			yyVAL.node = scalar.NewEncapsed(yyDollar[1].token, nil, yyDollar[2].token)
		}
	case 407:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:985
		{
			yyVAL.node = scalar.NewEncapsed(yyDollar[1].token, yyDollar[2].list, yyDollar[3].token)
		}
	case 408:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:986
		{
			yyVAL.node = scalar.NewEncapsed(yyDollar[1].token, yyDollar[2].list, yyDollar[3].token)
		}
	case 409:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:987
		{
			yyVAL.node = yyDollar[1].node
		}
	case 410:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:988
		{
			yyVAL.node = yyDollar[1].node
		}
	case 411:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:992
		{
			yyVAL.node = node.NewSimpleNode("Const").Append(yyDollar[1].node)
		}
	case 412:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:993
		{
			yyVAL.node = expr.NewClassConstFetch(yyDollar[1].node, yyDollar[3].token)
		}
	case 413:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:995
		{
			yyVAL.node = expr.NewClassConstFetch(yyDollar[1].node, yyDollar[3].token)
		}
	case 414:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:999
		{
			yyVAL.node = yyDollar[1].node
		}
	case 415:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1000
		{
			yyVAL.node = yyDollar[1].node
		}
	case 416:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:1004
		{
			yyVAL.node = node.NewSimpleNode("optional node. TODO: must be nil")
		}
	case 417:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1005
		{
			yyVAL.node = yyDollar[1].node
		}
	case 418:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1009
		{
			yyVAL.node = yyDollar[1].node
		}
	case 419:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1013
		{
			yyVAL.node = yyDollar[1].node
		}
	case 420:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1014
		{
			yyVAL.node = yyDollar[2].node
		}
	case 421:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1015
		{
			yyVAL.node = yyDollar[1].node
		}
	case 422:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1019
		{
			yyVAL.node = yyDollar[1].node
		}
	case 423:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1020
		{
			yyVAL.node = yyDollar[2].node
		}
	case 424:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1021
		{
			yyVAL.node = yyDollar[1].node
		}
	case 425:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1025
		{
			yyVAL.node = yyDollar[1].node
		}
	case 426:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:1026
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)
		}
	case 427:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:1027
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)
		}
	case 428:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:1028
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)
		}
	case 429:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:1030
		{
			yyVAL.node = node.NewSimpleNode("MethodCall").Append(yyDollar[1].node).Append(yyDollar[3].node).Append(yyDollar[4].node)
		}
	case 430:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1031
		{
			yyVAL.node = yyDollar[1].node
		}
	case 431:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1035
		{
			yyVAL.node = yyDollar[1].node
		}
	case 432:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1036
		{
			yyVAL.node = yyDollar[1].node
		}
	case 433:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1037
		{
			yyVAL.node = node.NewSimpleNode("Property").Append(yyDollar[1].node).Append(yyDollar[3].node)
		}
	case 434:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1041
		{
			yyVAL.node = node.NewSimpleNode("Variable").Attribute("name", yyDollar[1].token.String())
		}
	case 435:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:1042
		{
			yyVAL.node = node.NewSimpleNode("Variable").Append(yyDollar[3].node)
		}
	case 436:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:1043
		{
			yyVAL.node = node.NewSimpleNode("Variable").Append(yyDollar[2].node)
		}
	case 437:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1048
		{
			yyVAL.node = node.NewSimpleNode("StaticProp").Append(yyDollar[1].node).Append(yyDollar[3].node)
		}
	case 438:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1050
		{
			yyVAL.node = node.NewSimpleNode("StaticProp").Append(yyDollar[1].node).Append(yyDollar[3].node)
		}
	case 439:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1054
		{
			yyVAL.node = yyDollar[1].node
		}
	case 440:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:1055
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)
		}
	case 441:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:1056
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)
		}
	case 442:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1057
		{
			yyVAL.node = node.NewSimpleNode("Property").Append(yyDollar[1].node).Append(yyDollar[3].node)
		}
	case 443:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1059
		{
			yyVAL.node = node.NewSimpleNode("StaticProperty").Append(yyDollar[1].node).Append(yyDollar[3].node)
		}
	case 444:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1061
		{
			yyVAL.node = node.NewSimpleNode("StaticProperty").Append(yyDollar[1].node).Append(yyDollar[3].node)
		}
	case 445:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1065
		{
			yyVAL.node = node.NewSimpleNode("MemberName").Attribute("value", yyDollar[1].token.Value)
		}
	case 446:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1066
		{
			yyVAL.node = yyDollar[2].node
		}
	case 447:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1067
		{
			yyVAL.node = yyDollar[1].node
		}
	case 448:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1071
		{
			yyVAL.node = node.NewSimpleNode("PropertyName").Attribute("value", yyDollar[1].token.String())
		}
	case 449:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1072
		{
			yyVAL.node = yyDollar[2].node
		}
	case 450:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1073
		{
			yyVAL.node = yyDollar[1].node
		}
	case 451:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1077
		{ /* TODO: allow single trailing comma */
			yyVAL.node = yyDollar[1].node
		}
	case 452:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line parser/parser.y:1081
		{
			yyVAL.node = node.NewSimpleNode("TODO: must be nil")
		}
	case 453:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1082
		{
			yyVAL.node = yyDollar[1].node
		}
	case 454:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1087
		{
			yyVAL.node = yyDollar[1].node.Append(yyDollar[3].node)
		}
	case 455:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1088
		{
			yyVAL.node = node.NewSimpleNode("ArrayPairList").Append(yyDollar[1].node)
		}
	case 456:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1092
		{
			yyVAL.node = expr.NewArrayItem(yyDollar[1].node, yyDollar[3].node, false)
		}
	case 457:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1093
		{
			yyVAL.node = expr.NewArrayItem(nil, yyDollar[1].node, false)
		}
	case 458:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:1094
		{
			yyVAL.node = expr.NewArrayItem(yyDollar[1].node, yyDollar[4].node, true)
		}
	case 459:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:1095
		{
			yyVAL.node = expr.NewArrayItem(nil, yyDollar[2].node, true)
		}
	case 460:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser/parser.y:1097
		{
			fmt.Println("\nHellow world\n")
			yyVAL.node = expr.NewArrayItem(yyDollar[1].node, node.NewSimpleNode("List").Append(yyDollar[5].node), true)
		}
	case 461:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:1102
		{
			yyVAL.node = expr.NewArrayItem(nil, node.NewSimpleNode("List").Append(yyDollar[3].node), true)
		}
	case 462:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:1108
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)
		}
	case 463:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:1109
		{
			yyVAL.list = append(yyDollar[1].list, scalar.NewEncapsedStringPart(yyDollar[2].token))
		}
	case 464:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1110
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 465:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:1111
		{
			yyVAL.list = []node.Node{scalar.NewEncapsedStringPart(yyDollar[1].token), yyDollar[2].node}
		}
	case 466:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1115
		{
			yyVAL.node = node.NewSimpleNode("Variable").Attribute("value", yyDollar[1].token.String())
		}
	case 467:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:1116
		{
			yyVAL.node = expr.NewArrayDimFetch(expr.NewVariable(yyDollar[1].token), yyDollar[3].node)
		}
	case 468:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1117
		{
			yyVAL.node = node.NewSimpleNode("Variable").Attribute("value", yyDollar[1].token.String()).Append(node.NewSimpleNode("property").Attribute("value", yyDollar[3].token.String()))
		}
	case 469:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1118
		{
			yyVAL.node = node.NewSimpleNode("Variable").Append(node.NewSimpleNode("expr").Append(yyDollar[2].node))
		}
	case 470:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1119
		{
			yyVAL.node = node.NewSimpleNode("Variable").Attribute("value", yyDollar[2].token.String())
		}
	case 471:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line parser/parser.y:1121
		{
			yyVAL.node = expr.NewArrayDimFetch(expr.NewVariable(yyDollar[2].token), yyDollar[4].node)
		}
	case 472:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1122
		{
			yyVAL.node = yyDollar[2].node
		}
	case 473:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1125
		{
			yyVAL.node = node.NewSimpleNode("OffsetString").Attribute("value", yyDollar[1].token.String())
		}
	case 474:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1126
		{
			yyVAL.node = node.NewSimpleNode("OffsetNumString").Attribute("value", yyDollar[1].token.String())
		}
	case 475:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:1127
		{
			yyVAL.node = node.NewSimpleNode("OffsetNegateNumString").Attribute("value", yyDollar[2].token.String())
		}
	case 476:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1128
		{
			yyVAL.node = node.NewSimpleNode("OffsetVariable").Attribute("value", yyDollar[1].token.String())
		}
	case 477:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line parser/parser.y:1132
		{
			yyVAL.node = yyDollar[3].node
		}
	case 478:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:1133
		{
			yyVAL.node = node.NewSimpleNode("Empty").Append(yyDollar[3].node)
		}
	case 479:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:1134
		{
			yyVAL.node = node.NewSimpleNode("Include").Append(yyDollar[2].node)
		}
	case 480:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:1135
		{
			yyVAL.node = node.NewSimpleNode("IncludeOnce").Append(yyDollar[2].node)
		}
	case 481:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line parser/parser.y:1136
		{
			yyVAL.node = node.NewSimpleNode("Eval").Append(yyDollar[3].node)
		}
	case 482:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:1137
		{
			yyVAL.node = node.NewSimpleNode("Require").Append(yyDollar[2].node)
		}
	case 483:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line parser/parser.y:1138
		{
			yyVAL.node = node.NewSimpleNode("RequireOnce").Append(yyDollar[2].node)
		}
	case 484:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1142
		{
			yyVAL.node = yyDollar[1].node
		}
	case 485:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line parser/parser.y:1143
		{
			yyVAL.node = node.NewSimpleNode("AndIsset").Append(yyDollar[1].node).Append(yyDollar[3].node)
		}
	case 486:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line parser/parser.y:1147
		{
			yyVAL.node = node.NewSimpleNode("Isset").Append(yyDollar[1].node)
		}
	}
	goto yystack /* stack new state and value */
}
